﻿var PermissionRecord = Ext.data.Record.create([
    { name: 'name', mapping: 'name' },
    { name: 'type', mapping: 'type' },
    { name: 'icon', mapping: 'icon' },
    { name: 'permission', mapping: 'permission' }
]);

var MemberRecord = Ext.data.Record.create([
    { name: 'name', mapping: 'name' },
    { name: 'icon', mapping: 'icon' }
]);

var browserContextMenuTypes = ['textarea', 'text'];
var denyEditAD = htcConfig.winAuth && !htcConfig.enableADUsersGroupsEdit;
var showListForAllowedFolders = false;
var ajaxRequestTimeout = 180000; // in milliseconds 3 min

Ext.onReady(function() {

    Ext.QuickTips.init();

    try {
        Ext.util.Observable.observeClass(Ext.data.Connection);
        Ext.data.Connection.on('requestcomplete', function(dataconn, response){
            // we can search something special in response text response.responseText;
            try
            {
                var status = null;
                if(response.getResponseHeader)
                    status = response.getResponseHeader("X-HttpCommander-Status");
                if(status && status == 0)
                    location.href = htcConfig.relativePath + "Logout.aspx";
            }
            catch(e){ if(debugmode) throw e;};
        });
    }
    catch (e) {
        if (debugmode) throw e;
    }

    if (htcConfig
            && htcConfig.listAllowedFoldersPaths
                && htcConfig.allowedFoldersPaths
                    && htcConfig.allowedFoldersPaths.length > 0) {
        showListForAllowedFolders = htcConfig.listAllowedFoldersPaths > 0;
    }
    
    Ext.getDoc().on('contextmenu', function (event, object) {
        try
        {
            if (object && object.type && browserContextMenuTypes.indexOf(object.type.toLowerCase()) != -1) {
                if (window.event)
                    window.event.returnValue = true;
                return true;
            }
            else {
                event.stopEvent();
                return false;
            }
        }
        catch (e) { };
    });

    Ext.Direct.addProvider(HttpCommander.Remote.AdminHandler);
    var loadingMask = Ext.get('loading-mask');
    var loading = Ext.get('loading');
    if (loading) {
        loading.fadeOut({ duration: 0.2, remove: true });
        loadingMask.setOpacity(0.9);
        loadingMask.shift({
            xy: loading.getXY(),
            width: loading.getWidth(),
            height: loading.getHeight(),
            remove: true,
            duration: 1,
            opacity: 0.1,
            easing: 'bounceOut'
        });
    }

    addUserWindow = new Ext.Window({
        title: htcConfig.locData.AdminUsersPropertiesTitle,
        bodyStyle: 'padding:5px',
        layout: 'table',
        layoutConfig: { columns: 2 },
        resizable: false,
        closeAction: 'hide',
        width: 325,
        items:
        [
            addUserInfo = new Ext.form.FieldSet({
                title: htcConfig.locData.AdminUsersGeneralInfo,
                labelWidth: 100,
                defaultType: 'textfield',
                items:
                [
                    {
                        fieldLabel: htcConfig.locData.AdminUsersUserName,
                        id: 'add-user-name',
                        name: 'name',
                        width: 170
                    },
                    {
                        fieldLabel: htcConfig.locData.AdminUsersUserPassword,
                        id: 'add-user-password',
                        name: 'password',
                        inputType: 'password',
                        width: 170
                    },
                    {
                        fieldLabel: htcConfig.locData.AdminUsersUserPasswordRepeat,
                        id: 'add-user-password2',
                        name: 'password2',
                        inputType: 'password',
                        width: 170
                    },
                    {
                        fieldLabel: htcConfig.locData.AdminUsersUserEmail,
                        id: 'add-user-email',
                        name: 'email',
                        width: 170
                    },
                    {
                        fieldLabel: htcConfig.locData.AdminCommonCustomField,
                        id: 'add-user-custom-field',
                        name: 'customField',
                        width: 170
                    }
                ]
            })
        ],
        buttons:
        [
            {
                text: htcConfig.locData.AdminUsersAdd,
                id: 'add',
                handler: function() {
                    var validationResult = validateAddUserData();
                    if (validationResult) {
                        Ext.Msg.show({
                            title: htcConfig.locData.CommonErrorCaption,
                            msg: validationResult,
                            icon: Ext.MessageBox.WARNING,
                            buttons: Ext.Msg.OK
                        });
                    }
                    else {
                        addUserWindow.hide();
                        var user = aggregateAddUserData();
                        gridUsers.loadMask.msg = htcConfig.locData.ProgressCreating + "...";
                        gridUsers.loadMask.show();
                        HttpCommander.Admin.AddUser(user, function(data, trans) {
                            gridUsers.loadMask.msg = htcConfig.locData.ProgressLoading + "...";
                            if (data == undefined) {
                                Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, trans.message);
                                return;
                            }
                            if (data.status != "success") {
                                Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, data.message);
                            }
                            gridUsers.getStore().reload();
                        });
                    }
                }
            },
            {
                text: htcConfig.locData.AdminUsersCancel,
                handler: function() { addUserWindow.hide(); }
            },
            {
                text: htcConfig.locData.AdminUsersHelp,
                handler: function() { navigateHelp(); }
            }
        ]
    });

    editUserWindow = new Ext.Window({
        title: htcConfig.locData.AdminUsersPropertiesTitle,
        bodyStyle: 'padding:5px',
        layout: 'table',
        layoutConfig: { columns: 2 },
        resizable: false,
        closeAction: 'hide',
        width: 300,
        items:
        [
            editUserInfo = new Ext.form.FieldSet({
                title: htcConfig.locData.AdminUsersGeneralInfo,
                labelWidth: 75,
                defaultType: 'textfield',
                /* name of the edited user
                Since this form allows to change the name of the existing user,
                we need to store the original name. */
                userName: '',
                items:
                [
                    {
                        fieldLabel: htcConfig.locData.AdminUsersUserName,
                        id: 'edit-user-name',
                        name: 'name',
                        width: 170
                    },
                    {
                        fieldLabel: htcConfig.locData.AdminUsersUserEmail,
                        id: 'edit-user-email',
                        name: 'email',
                        width: 170
                    },
                    {
                        fieldLabel: htcConfig.locData.AdminCommonCustomField,
                        id: 'edit-user-custom-field',
                        name: 'customField',
                        width: 170
                    }
                ]
            })
        ],
        buttons:
        [
            {
                text: htcConfig.locData.AdminUsersUpdate,
                id: 'edit',
                handler: function() {
                    var validationResult = validateEditUserData();
                    if (validationResult) {
                        Ext.Msg.show({
                            title: htcConfig.locData.CommonErrorCaption,
                            msg: validationResult,
                            icon: Ext.MessageBox.WARNING,
                            buttons: Ext.Msg.OK
                        });
                    }
                    else {
                        editUserWindow.hide();
                        var user = aggregateEditUserData();
                        HttpCommander.Admin.UpdateUser(user, function(data, trans) {
                            gridUsers.loadMask.msg = htcConfig.locData.ProgressUpdating + "...";
                            if (data == undefined) {
                                Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, trans.message);
                                return;
                            }
                            if (data.status != "success") {
                                Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, data.message);
                            }
                            else if (data.digest) // Added by ChessarX, 21.02.2011
                                Ext.Msg.alert(htcConfig.locData.CommonWarningCaption, data.digest);
                            gridUsers.getStore().reload();
                        });
                    }
                }
            },
            {
                text: htcConfig.locData.AdminUsersCancel,
                handler: function() { editUserWindow.hide(); }
            },
            {
                text: htcConfig.locData.AdminUsersHelp,
                handler: function() { navigateHelp(); }
            }
        ]
    });

    setUserPasswordWindow = new Ext.Window({
        title: htcConfig.locData.AdminUsersSetPasswordTitle,
        bodyStyle: 'padding:5px',
        layout: 'table',
        layoutConfig: { columns: 2 },
        resizable: false,
        closeAction: 'hide',
        width: 325,
        items:
        [
            setUserPasswordInfo = new Ext.form.FieldSet({
                title: htcConfig.locData.AdminUsersGeneralInfo,
                labelWidth: 100,
                defaultType: 'textfield',
                items:
                [
                    {
                        fieldLabel: htcConfig.locData.AdminUsersUserName,
                        id: 'set-user-password-name',
                        name: 'name',
                        disabled: true,
                        width: 170
                    },
                    {
                        fieldLabel: htcConfig.locData.AdminUsersUserPassword,
                        id: 'set-user-password-password',
                        name: 'password',
                        inputType: 'password',
                        width: 170
                    },
                    {
                        fieldLabel: htcConfig.locData.AdminUsersUserPasswordRepeat,
                        id: 'set-user-password-password2',
                        name: 'password2',
                        inputType: 'password',
                        width: 170
                    }
                ]
            })
        ],
        buttons:
        [
            {
                text: htcConfig.locData.AdminUsersUpdate,
                id: 'save',
                handler: function() {
                    var validationResult = validateSetUserPasswordData();
                    if (validationResult) {
                        Ext.Msg.show({
                            title: htcConfig.locData.CommonErrorCaption,
                            msg: validationResult,
                            icon: Ext.MessageBox.WARNING,
                            buttons: Ext.Msg.OK
                        });
                    }
                    else {
                        setUserPasswordWindow.hide();
                        var user = aggregateSetUserPasswordData();
                        HttpCommander.Admin.SetUserPassword(user, function(data, trans) {
                            gridUsers.loadMask.msg = htcConfig.locData.ProgressUpdating + "...";
                            if (data == undefined) {
                                Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, trans.message);
                                return;
                            }
                            if (data.status != "success") {
                                Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, data.message);
                            }
                            gridUsers.getStore().reload();
                        });
                    }
                }
            },
            {
                text: htcConfig.locData.AdminUsersCancel,
                handler: function() { setUserPasswordWindow.hide(); }
            },
            {
                text: htcConfig.locData.AdminUsersHelp,
                handler: function() { navigateHelp(); }
            }
        ]
    });
    
    groupWindow = new Ext.Window({
        title: htcConfig.locData.AdminGroupsPropertiesTitle,
        isEditing: false,
        bodyStyle: 'padding:5px',
        layout: 'table',
        layoutConfig: { columns: 1 },
        resizable: false,
        closeAction: 'hide',
        width: 260,
        items:
        [
            groupInfo = new Ext.form.FieldSet({
                title: htcConfig.locData.AdminGroupsGeneralInfo,
                labelWidth: 75,
                defaultType: 'textfield',
                /* '' if isEditing is false,
                name of the edited user if isEditing is true.
                Since this form allows to change the name of the existing group,
                we need to store the original name. */
                groupName: '',
                items:
                [
                    {
                        fieldLabel: htcConfig.locData.AdminGroupsGroupName,
                        id: 'group-name',
                        name: 'name',
                        width: 130
                    },
                    {
                        fieldLabel: htcConfig.locData.AdminCommonCustomField,
                        id: 'group-custom-field',
                        name: 'customField',
                        width: 130
                    }
                ]
            }),
            gridMembers = new Ext.grid.GridPanel({
                store: new Ext.data.ArrayStore({
                    fields: ['name', 'icon']
                }),
                multiSelect: false,
                height: 200,
                enableHdMenu: false,
                header: true,
                title: htcConfig.locData.AdminGroupsUsers,
                selModel: new Ext.grid.RowSelectionModel({
                    singleSelect: true,
                    listeners: {
                        selectionchange: function(model) {
                            var removeButton = gridMembers.getTopToolbar().findById('remove-member');
                            removeButton.setDisabled(model.getCount() == 0);
                        } 
                    }
                }),
                tbar: {
                    enableOverflow: true,
                    items:
                [
                    {
                        text: htcConfig.locData.AdminGroupsAddUser + '...', 
                        id: 'add-member', 
                        icon: htcConfig.relativePath + 'Images/add.png',
                        handler: function() {
                            promptUserName(function(btn, text) {
                                if (btn == 'ok') {
                                    var userExists = false;
                                    Ext.each(gridMembers.getStore().data.items, function(item) {
                                        if (item.data.name.toLowerCase() == text.toLowerCase()) userExists = true;
                                    });
                                    if (userExists) {
                                        Ext.Msg.show({
                                            title: htcConfig.locData.CommonErrorCaption,
                                            msg: htcConfig.locData.AdminGroupsUserAlreadyExists,
                                            icon: Ext.MessageBox.WARNING,
                                            buttons: Ext.Msg.OK
                                        });
                                    }
                                    else {
                                        var newRecord = new MemberRecord({
                                            name: text,
                                            icon: 'Images/user.png'
                                        });
                                        gridMembers.getStore().add(newRecord);
                                    }
                                }
                            });
                        }
                    },
                    {
                        text: htcConfig.locData.AdminGroupsRemoveUser, id: 'remove-member', icon: htcConfig.relativePath + 'Images/remove.png', disabled: true,
                        handler: function() {
                            var selectedRecord = gridMembers.getSelectionModel().getSelected();
                            if (selectedRecord) gridMembers.getStore().remove(selectedRecord);
                        }
                    }
                ]},
                columns:
                [
                    {
                        header: htcConfig.locData.AdminGroupsUserNameColumn,
                        width: 215,
                        dataIndex: 'name',
                        renderer: function(value, p, r) {
                            return "<img src='" + htcConfig.relativePath + r.data.icon + "' class='filetypeimage'>" + value;
                        }
                    }
                ]
            })
        ],
        buttons:
        [
            {
                text: htcConfig.locData.AdminGroupsAdd,
                id: 'add-edit-group',
                handler: function() {
                    //updatePermission();
                    var validationResult = validateGroupData();
                    if (validationResult) {
                        Ext.Msg.show({
                            title: htcConfig.locData.CommonErrorCaption,
                            msg: validationResult,
                            icon: Ext.MessageBox.WARNING,
                            buttons: Ext.Msg.OK
                        });
                    }
                    else {
                        groupWindow.hide();
                        var group = aggregateGroupData();
                        if (!groupWindow.isEditing) {
                            gridGroups.loadMask.msg = htcConfig.locData.ProgressCreating + "...";
                            gridGroups.loadMask.show();
                            HttpCommander.Admin.AddGroup(group, function(data, trans) {
                                gridGroups.loadMask.msg = htcConfig.locData.ProgressLoading + "...";
                                if (data == undefined) {
                                    Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, trans.message);
                                    return;
                                }     
                                if (data.status != "success") {
                                    Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, data.message);
                                }
                                gridGroups.getStore().reload();
                            });
                        }
                        else {
                            HttpCommander.Admin.UpdateGroup(group, function(data, trans) {
                                gridGroups.loadMask.msg = htcConfig.locData.ProgressUpdating + "...";
                                if (data == undefined) {
                                    Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, trans.message);
                                    return;
                                }
                                if (data.status != "success") {
                                    Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, data.message);
                                }
                                gridGroups.getStore().reload();
                            });
                        }
                    }
                }
            },
            {
                text: htcConfig.locData.AdminGroupsCancel,
                handler: function() { groupWindow.hide(); }
            },
            {
                text: htcConfig.locData.AdminGroupsHelp,
                handler: function() { navigateHelp(); }
            }
        ]
    });

    var commonFolderInfoItems =
    [
        {
            fieldLabel: htcConfig.locData.AdminFoldersFolderName,
            id: 'folder-name',
            name: 'name',
            width: 220
        }
    ];
    if (showListForAllowedFolders)
        commonFolderInfoItems.push({
            xtype: 'combo',
            fieldLabel: htcConfig.locData.AdminFoldersFolderPath,
            name: 'path',
            width: 220,
            id: 'folder-path',
            displayField: 'path',
            mode: 'remote',
            tpl: '<tpl for="."><div ext:qtip="{path}" class="x-combo-list-item">{path}</div></tpl>',
            triggerAction: 'all',
            loadingText: htcConfig.locData.ProgressLoading + '...',
            //selectOnFocus: true,
            forceSelection: true,
            editable: false,
            lazyInit: false,
            store: new Ext.data.DirectStore({
                directFn: HttpCommander.Admin.GetAllowedFolders,
                autoLoad: false,
                fields: [ 'path' ]
            }),
            listeners: {
                'select': function (combo, record, index) {
                    Ext.QuickTips.getQuickTip().register({
                        target: this.el,
                        text: record.data.path
                    });
                }
            }
        });
    else
        commonFolderInfoItems.push({
            fieldLabel: htcConfig.locData.AdminFoldersFolderPath,
            id: 'folder-path',
            name: 'path',
            width: 220
        });
    commonFolderInfoItems.push({
            labelWidth: 75,
            fieldLabel: '_',
            labelStyle: 'color:#dfe8f6;',
            width: 220,
            defaultType: 'button',
            layout: 'column',//'hbox',
            xtype: 'container',
            height: 30,
            items:
            [
                {
                    xtype: 'button',
                    hidden: !htcConfig.winAuth,
                    text: htcConfig.locData.AdminFoldersSharesButton,
                    handler: function() {
                        promptShareName(function(btn, text) {
                            if (btn == 'ok') {
                                Ext.getCmp('folder-path').setValue(text);
                            }
                        });
                    },
                    columnWidth: .45
                },
                {
                    xtype: 'label',
                    html: '&nbsp;&nbsp;&nbsp;',
                    columnWidth: htcConfig.winAuth ? .1 : .55
                },
                {
                    xtype: 'button',
                    columnWidth: .45,
                    text: htcConfig.locData.AdminFoldersTestAccessButton,
                    handler: function() {
                        var pathInfo = { path: Ext.getCmp('folder-path').getValue() };
                        gridFolders.loadMask.msg = htcConfig.locData.ProgressTestAccess + "...";
                        gridFolders.loadMask.show();
                        HttpCommander.Admin.TestAccess(pathInfo, function(data, trans) {
                            gridFolders.loadMask.hide();
                            gridFolders.loadMask.msg = htcConfig.locData.ProgressLoading + "...";
                            if (data == undefined) {
                                Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, trans.message);
                                return;
                            }
                            Ext.Msg.show({
                                title: htcConfig.locData.AdminFoldersTestAccessButton,
                                msg: data.message,
                                closable: true,
                                modal: true,
                                buttons: Ext.Msg.OK,
                                icon: data.error ? Ext.Msg.ERROR : (data.success ? Ext.Msg.INFO : Ext.Msg.WARNING)
                            });
                        });
                    }
                }
            ]
        });
    commonFolderInfoItems.push({
        fieldLabel: htcConfig.locData.AdminFoldersFolderDescription,
        xtype: 'textarea',
        id: 'folder-description',
        name: 'path',
        width: 220,
        height: 40
    });
    commonFolderInfoItems.push({
        fieldLabel: htcConfig.locData.AdminCommonCustomField,
        xtype: 'textarea',
        id: 'folder-custom-field',
        name: 'customField',
        width: 220,
        height: 40
    });    
    folderWindow = new Ext.Window({
        title: htcConfig.locData.AdminFoldersPropertiesTitle,
        width: 600,
        //height: 550,
        isEditing: false,
        bodyStyle: 'padding:5px',
        layout: 'table',
        layoutConfig: { columns: 2 },
        resizable: false,
        closeAction: 'hide',
        items:
        [
            commonFolderInfo = new Ext.form.FieldSet({
                title: htcConfig.locData.AdminFoldersGeneralInfo,
                labelWidth: 75,
                defaultType: 'textfield',
                items: commonFolderInfoItems
            }),
            fpPermissions = new Ext.form.FormPanel({
                height: 410 + 40 + 40 + 48,
                width: 250,
                //frame: true,
                cellCls: 'tlcell',
                bodyStyle: 'padding:5px',
                rowspan: 2,
                header: true,
                disabled: true,
                title: htcConfig.locData.AdminFoldersPermissions,
                items:
                [
                    new Ext.form.FieldSet({
                        title: htcConfig.locData.AdminFoldersAccessControl,
                        id: 'access',
                        layout: 'column',
                        defaults: { columnWidth: '.5', border: false },
                        defaultType: 'checkbox',
                        items:
                        [
                            { name: 'create', boxLabel: htcConfig.locData.AdminFoldersCreate, id: 'create' },
                            { name: 'del', boxLabel: htcConfig.locData.AdminFoldersDelete, id: 'del' },
                            { name: 'rename', boxLabel: htcConfig.locData.AdminFoldersRename, id: 'rename' },
                            { name: 'upload', boxLabel: htcConfig.locData.AdminFoldersUpload, id: 'upload' },
                            { name: 'download', boxLabel: htcConfig.locData.AdminFoldersDownload, id: 'download' },
                            { name: 'zipDownload', boxLabel: htcConfig.locData.AdminFoldersZipDownload, id: 'zipDownload' },
                            { name: 'zip', boxLabel: htcConfig.locData.AdminFoldersZip, id: 'zip' },
                            { name: 'unzip', boxLabel: htcConfig.locData.AdminFoldersUnzip, id: 'unzip' },
                            { name: 'cut', boxLabel: htcConfig.locData.AdminFoldersCut, id: 'cut' },
                            { name: 'copy', boxLabel: htcConfig.locData.AdminFoldersCopy, id: 'copy' },
                            { name: 'listFiles', boxLabel: htcConfig.locData.AdminFoldersListFiles, id: 'listFiles' },
                            { name: 'listFolders', boxLabel: htcConfig.locData.AdminFoldersListFolders, id: 'listFolders' },
                            { name: 'modify', boxLabel: htcConfig.locData.AdminFoldersModify, id: 'modify' } // Added by ChessarX, 16.02.2011
                        ]
                    }),
                    new Ext.form.FieldSet({
                        title: htcConfig.locData.AdminFoldersListRestrictions,
                        labelWidth: 60,
                        width: 236,
                        items:
                        [
                            {
                                xtype: 'radiogroup',
                                fieldLabel: htcConfig.locData.AdminFoldersRestrictionType,
                                id: 'list-rest',
                                items:
                                [
                                    { boxLabel: htcConfig.locData.AdminFoldersRestrictionAllow, name: 'listType', inputValue: 0 },
                                    { boxLabel: htcConfig.locData.AdminFoldersRestrictionDeny, name: 'listType', inputValue: 1, checked: true }
                                ]
                            },
                            {
                                name: 'list-ext', id: 'list-ext', fieldLabel: htcConfig.locData.AdminFoldersRestrictionExtensions, enableKeyEvents: true,
                                width: 130, xtype: 'textfield', style: { textTransform: "uppercase" }
                            }
                        ]
                    }),
                    new Ext.form.FieldSet({
                        title: htcConfig.locData.AdminFoldersCreateRestrictions,
                        labelWidth: 60,
                        width: 236,
                        items:
                        [
                            {
                                xtype: 'radiogroup',
                                id: 'create-rest',
                                fieldLabel: htcConfig.locData.AdminFoldersRestrictionType,
                                items:
                                [
                                    { boxLabel: htcConfig.locData.AdminFoldersRestrictionAllow, name: 'createType', inputValue: 0 },
                                    { boxLabel: htcConfig.locData.AdminFoldersRestrictionDeny, name: 'createType', inputValue: 1, checked: true }
                                ]
                            },
                            { name: 'create-ext', id: 'create-ext', fieldLabel: htcConfig.locData.AdminFoldersRestrictionExtensions, width: 130, xtype: 'textfield', style: { textTransform: "uppercase"} }
                        ]
                    }),
                    {
                        name: 'customField',
                        id: 'folders-permissions-custom-field',
                        xtype: 'textfield',
                        fieldLabel: htcConfig.locData.AdminCommonCustomField
                    }
                ]
            }),
            gridPerms = new Ext.grid.GridPanel({
                store: new Ext.data.ArrayStore({
                    fields: ['name', 'type', 'typeId', 'icon', 'permission']//,
                    //data: []
                }),
                multiSelect: false,
                height: 308,
                width: 322,
                enableHdMenu: false,
                header: true,
                title: htcConfig.locData.AdminFoldersUsersGroups,
                selModel: new Ext.grid.RowSelectionModel({
                    singleSelect: true,
                    listeners: {
                        selectionchange: function(model) {
                            var removeButton = gridPerms.getTopToolbar().findById('remove');
                            removeButton.setDisabled(model.getCount() == 0);

                            var selectedRecord = gridPerms.getSelectionModel().getSelected();
                            fpPermissions.setDisabled(!selectedRecord);
                            fpPermissions.setTitle(!selectedRecord ? htcConfig.locData.AdminFoldersPermissions : String.format(htcConfig.locData.AdminFoldersPermissionsFor, selectedRecord.data.name));

                            if (selectedRecord) {
                                fillPermissionData(selectedRecord.data.permission, fpPermissions);
                            }
                        },
                        beforerowselect: function(model, rowIndex, keepExisting, record) {
                            updatePermission();
                        }
                    }
                }),
                tbar: {
                    enableOverflow: true,
                    items:
                [
                    {
                        text: htcConfig.locData.AdminFoldersAddUser + "...",
                        id: 'add-user',
                        icon: htcConfig.relativePath + 'Images/add.png',
                        handler: function() {
                            promptUserName(function(btn, text) {
                                if (btn == 'ok') {
                                    var userExists = false;
                                    Ext.each(gridPerms.getStore().data.items, function(item) {
                                        if (item.data.typeId == "user" && item.data.name.toLowerCase() == text.toLowerCase()) 
                                            userExists = true;
                                    });
                                    if (userExists) {
                                        Ext.Msg.show({
                                            title: htcConfig.locData.CommonErrorCaption,
                                            msg: htcConfig.locData.AdminFoldersUserAlreadyExists,
                                            icon: Ext.MessageBox.WARNING,
                                            buttons: Ext.Msg.OK
                                        });
                                    }
                                    else {
                                        var newRecord = new PermissionRecord({
                                            name: text,
                                            type: htcConfig.locData.AdminFoldersUserIdentity,
                                            typeId: 'user',
                                            icon: 'Images/user.png',
                                            permission: getDefaultPermission(text)
                                        });
                                        gridPerms.getStore().add(newRecord);
                                    }
                                }
                            });
                        }
                    },
                    {
                        text: htcConfig.locData.AdminFoldersAddGroup + '...', 
                        id: 'add-group', 
                        icon: htcConfig.relativePath + 'Images/add.png',
                        handler: function() {
                            promptGroupName(function(btn, text) {
                                if (btn == 'ok') {
                                    var groupExists = false;
                                    Ext.each(gridPerms.getStore().data.items, function(item) {
                                        if (item.data.typeId == "group" && item.data.name.toLowerCase() == text.toLowerCase())
                                            groupExists = true;
                                    });
                                    if (groupExists) {
                                        Ext.Msg.show({
                                            title: htcConfig.locData.CommonErrorCaption,
                                            msg: htcConfig.locData.AdminFoldersGroupAlreadyExists,
                                            icon: Ext.MessageBox.WARNING,
                                            buttons: Ext.Msg.OK
                                        });
                                    }
                                    else {
                                        var newRecord = new PermissionRecord({
                                            name: text,
                                            type: htcConfig.locData.AdminFoldersGroupIdentity,
                                            typeId: 'group',
                                            icon: 'Images/group.png',
                                            permission: getDefaultPermission(text)
                                        });
                                        gridPerms.getStore().add(newRecord);
                                    }
                                }
                            });
                        }
                    },
                    {
                        text: htcConfig.locData.AdminFoldersRemoveUserGroup, id: 'remove', icon: htcConfig.relativePath + 'Images/remove.png', disabled: true,
                        handler: function() {
                            var selectedRecord = gridPerms.getSelectionModel().getSelected();
                            if (selectedRecord) gridPerms.getStore().remove(selectedRecord);
                        }
                    }
                ]},
                columns:
                [
                    {
                        header: htcConfig.locData.AdminFoldersIdentityName,
                        width: 215,
                        dataIndex: 'name',
                        renderer: function(value, p, r) {
                            return "<img src='" + htcConfig.relativePath + r.data.icon + "' class='filetypeimage'>" + value;
                        }
                    },
                    {
                        header: htcConfig.locData.AdminFoldersIdentityType,
                        width: 80,
                        dataIndex: 'type'
                    }
                ]
            })
        ],
        buttons:
        [
            {
                text: htcConfig.locData.AdminFoldersAdd,
                id: 'add-edit-folder',
                handler: function() {
                    updatePermission();
                    var validationResult = validateFolderData();
                    if (validationResult) {
                        Ext.Msg.show({
                            title: htcConfig.locData.CommonErrorCaption,
                            msg: validationResult,
                            icon: Ext.MessageBox.WARNING,
                            buttons: Ext.Msg.OK
                        });
                    }
                    else {
                        folderWindow.hide();
                        var folder = aggregateFolderData();
                        if (!folderWindow.isEditing) {
                            gridFolders.loadMask.msg = htcConfig.locData.ProgressCreating + "...";
                            gridFolders.loadMask.show();
                            HttpCommander.Admin.AddFolder(folder, function(data, trans) {
                                gridFolders.loadMask.msg = htcConfig.locData.ProgressLoading + "...";
                                if (data == undefined) {
                                    Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, trans.message);
                                    return;
                                }
                                if (data.status != "success") {
                                    Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, data.message);
                                }
                                gridFolders.getStore().reload();
                            });
                        }
                        else {
                            HttpCommander.Admin.UpdateFolder(folder, function(data, trans) {
                                gridFolders.loadMask.msg = htcConfig.locData.ProgressUpdating + "...";
                                if (data == undefined) {
                                    Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, trans.message);
                                    return;
                                }
                                if (data.status != "success") {
                                    Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, data.message);
                                }
                                gridFolders.getStore().reload();
                            });
                        }
                    }
                }
            },
            {
                text: htcConfig.locData.AdminFoldersCancel,
                handler: function() { folderWindow.hide(); }
            },
            {
                text: htcConfig.locData.AdminFoldersHelp,
                handler: function() { navigateHelp(); }
            }
        ],
        listeners: {
            hide: function(window) {

            },
            show: function(window) {
                var comboField = window.findById('folder-path');
                if (comboField) {
                    var val = comboField.getValue();
                    if (val && val != '') {
                        Ext.QuickTips.getQuickTip().register({
                            target: comboField.el,
                            text: val
                        });
                    }
                } else {
                    Ext.QuickTips.getQuickTip().unregister(comboField.el);
                }
            }
        }
    });
    
    var adminTabs = new Ext.TabPanel({
        activeTab: 0,
        border: true,
        region: 'center',
        margins: '0 0 5 0',
        deferredRender: true,
        items:                 
        [
            {
                title: htcConfig.locData.AdminFoldersTab,
                id: 'folders-tab',
                layout: 'fit',
                items:
                [
                    gridFolders = new Ext.grid.GridPanel({
                        store: new Ext.data.DirectStore({
                            directFn: HttpCommander.Admin.GetFolders,
                            fields:
                            [
                                { name: 'name', type: 'string' },
                                { name: 'path', type: 'string' },
                                { name: 'icon', type: 'string' },
                                { name: 'description', type: 'string' },
                                { name: 'customField', type: 'string' },
                                { name: 'userPerms' },
                                { name: 'groupPerms' }
                            ]
                        }),
                        viewConfig: { forceFit: true },
                        multiSelect: false,
                        border: false,
                        loadMask: true,
                        enableHdMenu: false,
                        autoExpandColumn: 'path',
                        width: 352, height: 212,
                        selModel: new Ext.grid.RowSelectionModel({
                            singleSelect: true,
                            listeners: {
                                selectionchange: function(model) {
                                    var removeButton = gridFolders.getTopToolbar().findById('remove-folder');
                                    var editButton = gridFolders.getTopToolbar().findById('edit-folder');
                                    removeButton.setDisabled(model.getCount() == 0);
                                    editButton.setDisabled(model.getCount() == 0);
                                }
                            }
                        }),
                        tbar:
                        [
                            {
                                text: htcConfig.locData.CommandRefresh, icon: htcConfig.relativePath + 'Images/refresh.png',
                                handler: function() {
                                    gridFolders.getStore().reload();
                                }
                            },
                            {
                                text: htcConfig.locData.AdminFoldersAddFolder + '...', icon: htcConfig.relativePath + 'Images/add.png',
                                handler: function() {
                                    prepareFolderWindow(null);
                                    folderWindow.show();
                                }
                            },
                            {
                                text: htcConfig.locData.AdminFoldersEditFolder + '...', id: 'edit-folder', icon: htcConfig.relativePath + 'Images/edit.png', disabled: true,
                                handler: function() {
                                    var selectedRecord = gridFolders.getSelectionModel().getSelected();
                                    prepareFolderWindow(selectedRecord.data);
                                    folderWindow.show();
                                }
                            },
                            {
                                id: 'remove-folder', text: htcConfig.locData.AdminFoldersRemoveFolder,
                                icon: htcConfig.relativePath + 'Images/remove.png', disabled: true,
                                handler: function() {
                                    var selectedRecord = gridFolders.getSelectionModel().getSelected();
                                    var folderName = selectedRecord.data.name;
                                    var removeInfo = {};
                                    removeInfo["name"] = folderName;
                                    Ext.Msg.show({
                                        title: htcConfig.locData.CommonConfirmCaption,
                                        msg: String.format(htcConfig.locData.AdminFoldersDeleteFolderPrompt, folderName),
                                        buttons: Ext.Msg.YESNO,
                                        icon: Ext.MessageBox.QUESTION,
                                        fn: function(result) {
                                            if (result == "yes") {
                                                gridFolders.loadMask.msg = htcConfig.locData.ProgressDeleting + "...";
                                                gridFolders.loadMask.show();
                                                HttpCommander.Admin.DeleteFolder(removeInfo, function(data, trans) {
                                                    gridFolders.loadMask.msg = htcConfig.locData.ProgressLoading + "...";
                                                    if (data == undefined) {
                                                        Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, trans.message);
                                                        return;
                                                    }
                                                    if (data.status != "success") {
                                                        Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, data.message);
                                                    }
                                                    gridFolders.getStore().reload();
                                                });
                                            }
                                        }
                                    });
                                }
                            },
                            {
                                text: htcConfig.locData.AdminFoldersHelp, icon: htcConfig.relativePath + 'Images/help.png',
                                handler: function() { navigateHelp(); }
                            }
                        ],
                        columns:
                        [
                            {
                                id: 'name', sortable: true,
                                header: htcConfig.locData.FolderGridNameColumn,
                                width: 100,
                                dataIndex: 'name',
                                renderer: function(value, p, r) {
                                    return "<img src='" + htcConfig.relativePath + r.data.icon + "' class='filetypeimage'>" + value;
                                }
                            },
                            {
                                id: 'path',
                                width: 150,
                                header: htcConfig.locData.FolderGridPathColumn,
                                dataIndex: 'path'
                            },
                            {
                                id: 'userPerms',
                                width: 150,
                                header: htcConfig.locData.FolderGridUserPermissionsColumn,
                                dataIndex: 'userPerms',
                                renderer: identitiesRenderer
                            },
                            {
                                id: 'groupPerms',
                                width: 150,
                                header: htcConfig.locData.FolderGridGroupPermissionsColumn,
                                dataIndex: 'groupPerms',
                                renderer: identitiesRenderer
                            }
                        ]
                    })
                ]
            }
        ],
        listeners: {
            tabchange: function(thisPanel, tab) {
                if(tab.id == "folders-tab" && ! ("loaded_once" in tab)) {
                    tab.loaded_once = true;
                    gridFolders.store.load();
                } else if(tab.id == "users-tab" && ! ("loaded_once" in tab)) {
                    tab.loaded_once = true;
                    gridUsers.store.load();
                } else if(tab.id == "groups-tab" && ! ("loaded_once" in tab)) {
                    tab.loaded_once = true;
                    gridGroups.store.load();
                } else if(tab.id == "log-tab" && ! ("loaded_once" in tab)) {
                    tab.loaded_once = true;
                    gridLog.store.load();
                }
            }
        }
    });


    //if (!htcConfig.winAuth)
    //{
        adminTabs.add( 
            {
                title: htcConfig.locData.AdminUsersTab,
                layout: 'fit',
                id: 'users-tab',
                items:
                [
                    gridUsers = new Ext.grid.GridPanel({
                        store: new Ext.data.DirectStore({
                            directFn: HttpCommander.Admin.GetUsers,
                            fields:
                            [
                                { name: 'name', type: 'string' },
                                { name: 'email', type: 'string' },
                                { name: 'icon', type: 'string' },
                                { name: 'customField', type: 'string' }
                            ]
                        }),
                        viewConfig: { forceFit: true },
                        multiSelect: false,
                        border: false,
                        loadMask: true,
                        enableHdMenu: false,
                        autoExpandColumn: 'name',
                        width: 352, height: 212,
                        selModel: new Ext.grid.RowSelectionModel({
                            singleSelect: true,
                            listeners: {
                                selectionchange: function(model) {
                                    var removeButton = gridUsers.getTopToolbar().findById('remove-user');
                                    var editButton = gridUsers.getTopToolbar().findById('edit-user');
                                    var setPasswordButton = gridUsers.getTopToolbar().findById('set-user-password');
                                    removeButton.setVisible(!(model.getCount() == 0 || denyEditAD));
                                    editButton.setVisible(!(model.getCount() == 0 || denyEditAD));
                                    setPasswordButton.setVisible(!(model.getCount() == 0 || denyEditAD));
                                    removeButton.setDisabled(model.getCount() == 0 || denyEditAD);
                                    editButton.setDisabled(model.getCount() == 0 || denyEditAD);
                                    setPasswordButton.setDisabled(model.getCount() == 0 || denyEditAD);
                                }
                            }
                        }),
                        tbar:
                        [
                            {
                                text: htcConfig.locData.CommandRefresh, 
                                icon: htcConfig.relativePath + 'Images/refresh.png',
                                handler: function() {
                                    gridUsers.getStore().reload();
                                }
                            },                            
                            {
                                text: htcConfig.locData.AdminUsersAddUser + '...',
                                icon: htcConfig.relativePath + 'Images/add.png',
                                hidden: denyEditAD,
                                handler: function() {
                                    prepareAddUserWindow();
                                    addUserWindow.show();
                                }
                            },
                            {
                                text: htcConfig.locData.AdminUsersEditUser + '...', 
                                id: 'edit-user', 
                                icon: htcConfig.relativePath + 'Images/edit.png',
                                disabled: true,
                                hidden: denyEditAD,
                                handler: function() {
                                    var selectedRecord = gridUsers.getSelectionModel().getSelected();
                                    prepareEditUserWindow(selectedRecord.data);
                                    editUserWindow.show();
                                }
                            },
                            {
                                id: 'remove-user', 
                                text: htcConfig.locData.AdminUsersRemoveUser,
                                icon: htcConfig.relativePath + 'Images/remove.png',
                                disabled: true,
                                hidden: denyEditAD,
                                handler: function() {
                                    var selectedRecord = gridUsers.getSelectionModel().getSelected();
                                    var userName = selectedRecord.data.name;
                                    var removeInfo = {};
                                    removeInfo["name"] = userName;
                                    Ext.Msg.show({
                                        title: htcConfig.locData.CommonConfirmCaption,
                                        msg: String.format(htcConfig.locData.AdminUsersDeleteUserPrompt, userName),
                                        buttons: Ext.Msg.YESNO,
                                        icon: Ext.MessageBox.QUESTION,
                                        fn: function(result) {
                                            if (result == "yes") {
                                                gridUsers.loadMask.msg = htcConfig.locData.ProgressDeleting + "...";
                                                gridUsers.loadMask.show();
                                                HttpCommander.Admin.DeleteUser(removeInfo, function(data, trans) {
                                                    gridUsers.loadMask.msg = htcConfig.locData.ProgressLoading + "...";
                                                    if (data == undefined) {
                                                        Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, trans.message);
                                                        return;
                                                    }
                                                    if (data.status != "success") {
                                                        Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, data.message);
                                                    }
                                                    gridUsers.getStore().reload();
                                                });
                                            }
                                        }
                                    });
                                }
                            },
                            
                            {
                                id: 'set-user-password',
                                text: htcConfig.locData.AdminUsersSetUserPassword + '...',
                                icon: htcConfig.relativePath + 'Images/passwordreset.png',
                                disabled: true,
                                hidden: denyEditAD,
                                handler: function() {
                                    var selectedRecord = gridUsers.getSelectionModel().getSelected();
                                    prepareSetUserPasswordWindow(selectedRecord.data);
                                    setUserPasswordWindow.show();
                                }
                            },
                            {
                                text: htcConfig.locData.AdminUsersHelp, 
                                icon: htcConfig.relativePath + 'Images/help.png',
                                handler: function() { navigateHelp(); }
                            }
                        ],
                        columns:
                        [
                            {
                                id: 'name', sortable: true,
                                header: htcConfig.locData.UserGridNameColumn,
                                width: 100,
                                dataIndex: 'name',
                                renderer: function(value, p, r) {
                                    return "<img src='" + htcConfig.relativePath + r.data.icon + "' class='filetypeimage'>" + value;
                                }
                            }
                        ]
                    })
                ]
            }
        );
        adminTabs.add(
            {
                title: htcConfig.locData.AdminGroupsTab,
                layout: 'fit',
                id: 'groups-tab',
                items:
                [
                    gridGroups = new Ext.grid.GridPanel({
                        store: new Ext.data.DirectStore({
                            directFn: HttpCommander.Admin.GetGroups,
                            fields:
                            [
                                { name: 'name', type: 'string' },
                                { name: 'users' },
                                { name: 'icon', type: 'string' },
                                { name: 'customField', type: 'string' }
                            ]
                        }),
                        viewConfig: { forceFit: true },
                        multiSelect: false,
                        border: false,
                        loadMask: true,
                        enableHdMenu: false,
                        autoExpandColumn: 'name',
                        width: 352, height: 212,
                        selModel: new Ext.grid.RowSelectionModel({
                            singleSelect: true,
                            listeners: {
                                selectionchange: function(model) {
                                    var removeButton = gridGroups.getTopToolbar().findById('remove-group');
                                    var editButton = gridGroups.getTopToolbar().findById('edit-group');
                                    removeButton.setVisible(!(model.getCount() == 0 || denyEditAD));
                                    editButton.setVisible(!(model.getCount() == 0 || denyEditAD));
                                    removeButton.setDisabled(model.getCount() == 0 || denyEditAD);
                                    editButton.setDisabled(model.getCount() == 0 || denyEditAD);
                                }
                            }
                        }),
                        tbar:
                        [
                            {
                                text: htcConfig.locData.CommandRefresh, icon: htcConfig.relativePath + 'Images/refresh.png',
                                handler: function() {
                                    gridGroups.getStore().reload();
                                }
                            },
                            {
                                text: htcConfig.locData.AdminGroupsAddGroup + '...',
                                icon: htcConfig.relativePath + 'Images/add.png',
                                hidden: denyEditAD,
                                handler: function() {
                                    prepareGroupWindow(null);
                                    groupWindow.show();
                                }
                            },
                            {
                                text: htcConfig.locData.AdminGroupsEditGroup + '...', 
                                id: 'edit-group', 
                                icon: htcConfig.relativePath + 'Images/edit.png',
                                disabled: true,
                                hidden: denyEditAD,
                                handler: function() {
                                    var selectedRecord = gridGroups.getSelectionModel().getSelected();
                                    prepareGroupWindow(selectedRecord.data);
                                    groupWindow.show();
                                }
                            },
                            {
                                id: 'remove-group', text: htcConfig.locData.AdminGroupsRemoveGroup,
                                icon: htcConfig.relativePath + 'Images/remove.png',
                                disabled: true,
                                hidden: denyEditAD,
                                handler: function() {
                                    var selectedRecord = gridGroups.getSelectionModel().getSelected();
                                    var groupName = selectedRecord.data.name;
                                    var removeInfo = {};
                                    removeInfo["name"] = groupName;
                                    Ext.Msg.show({
                                        title: htcConfig.locData.CommonConfirmCaption,
                                        msg: String.format(htcConfig.locData.AdminGroupsDeleteGroupPrompt, groupName),
                                        buttons: Ext.Msg.YESNO,
                                        icon: Ext.MessageBox.QUESTION,
                                        fn: function(result) {
                                            if (result == "yes") {
                                                gridGroups.loadMask.msg = htcConfig.locData.ProgressDeleting + "...";
                                                gridGroups.loadMask.show();
                                                HttpCommander.Admin.DeleteGroup(removeInfo, function(data, trans) {
                                                    gridGroups.loadMask.msg = htcConfig.locData.ProgressLoading + "...";
                                                    if (data == undefined) {
                                                        Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, trans.message);
                                                        return;
                                                    }
                                                    if (data.status != "success") {
                                                        Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, data.message);
                                                    }
                                                    gridGroups.getStore().reload();
                                                });
                                            }
                                        }
                                    });
                                }
                            },
                            {
                                text: htcConfig.locData.AdminGroupsHelp, icon: htcConfig.relativePath + 'Images/help.png',
                                handler: function() { navigateHelp(); }
                            }
                        ],
                        columns:
                        [
                            {
                                id: 'name', sortable: true,
                                header: htcConfig.locData.GroupGridNameColumn,
                                width: 100,
                                dataIndex: 'name',
                                renderer: function(value, p, r) {
                                    return "<img src='" + htcConfig.relativePath + r.data.icon + "' class='filetypeimage'>" + value;
                                }
                            },
                            {
                                id: 'users',
                                width: 150,
                                header: htcConfig.locData.GroupGridUsersColumn,
                                dataIndex: 'users'
                            }
                        ]
                    })
                ]
            }
        );
    //}

    if (htcConfig.logs) {
        var logPageSize = 200;
        var logStore = new Ext.data.DirectStore({
            directFn: HttpCommander.Admin.GetLog,
            remoteSort: true,
            baseParams: { start: 0, limit: logPageSize },
            len: 4,
            paramOrder: ['start', 'limit', 'sort', 'dir'],
            totalProperty: 'total',
            root: 'data',
            paramNames: {start : 'start', limit : 'limit', sort : 'sort', dir : 'dir'},
            fields:
            [
                { name: 'user', type: 'string' },
                { name: 'type', type: 'string' },
                { name: 'date', type: 'date'   },
                { name: 'info', type: 'string' }
            ],
            sortInfo: {field: 'date', direction: 'DESC'}
        });
        adminTabs.add(
            {
                title: htcConfig.locData.AdminLogsTab,
                id: 'log-tab',
                layout: 'border',
                items:
                [
                    gridLog = new Ext.grid.GridPanel({
                        store: logStore,
                        viewConfig: { forceFit: true },
                        multiSelect: false,
                        border: false,
                        loadMask: true,
                        enableHdMenu: true,
                        autoExpandColumn: 'info',
                        region: 'center',
                        selModel: new Ext.grid.RowSelectionModel({
                            singleSelect: true,
                            listeners: {
                                selectionchange: function(model) {
                                    if(model.getCount() == 0)
                                        logDetailsPanel.update("");
                                    else
                                        var html = Ext.util.Format.htmlEncode(model.getSelected().data.info);
                                        logDetailsPanel.update(html);
                                }
                            }
                        }),
                        columns:
                        [
                            {
                                id: 'user', 
                                sortable: true,
                                header: htcConfig.locData.LogsGridUserNameColumn,
                                width: 40,
                                dataIndex: 'user'
                            },
                            {
                                id: 'type',
                                sortable: true,
                                width: 30,
                                header: htcConfig.locData.LogsGridTypeColumn,
                                dataIndex: 'type'
                            },
                            {
                                id: 'date',
                                sortable: true,
                                width: 50,
                                header: htcConfig.locData.LogsGridDateTimeColumn,
                                dataIndex: 'date',
                                renderer: dateRendererLocal
                            },
                            {
                                id: 'info',
                                sortable: true,
                                width: 250,
                                header: htcConfig.locData.LogsGridMoreInfoColumn,
                                dataIndex: 'info',
                                hidden: true
                            }
                        ],
                        tbar:
                        [
                            {
                                text: htcConfig.locData.CommandRefresh, icon: htcConfig.relativePath + 'Images/refresh.png',
                                handler: function() {
                                    gridLog.getStore().reload();
                                }
                            }
                        ],
                        plugins: 
                        [ 
                            new Ext.ux.grid.GridFilters({
                                local: true,
                                filters:
                                [
                                    {
                                        type: 'string',
                                        dataIndex: 'user'
                                    },
                                    {
                                        type: 'string',
                                        dataIndex: 'type'
                                    },
                                    {
                                        type: 'date',
                                        dataIndex: 'date'
                                    },
                                    {
                                        type: 'string',
                                        dataIndex: 'info'
                                    }
                                ]
                            })
                        ],
                        bbar: new Ext.PagingToolbar({
                            pageSize: logPageSize,
                            store: logStore,
                            displayInfo: true,
                            //displayMsg: htcConfig.locData.AdminLogsPagerInfo,
                            emptyMsg: htcConfig.locData.AdminLogsNoLogsMessage
                        })
                    }),
                    logDetailsPanel = new Ext.Panel({
                        //header: false,
                        title: htcConfig.locData.LogsGridDetailsTitle,
                        region: 'east',
                        split: true,
                        width: 200,
                        collapsible: true,
                        collapseMode: 'mini'
                    })
                ]
            }
        );
    }
    adminTabs.doLayout();
    
    Ext.QuickTips.init();

    var view = new Ext.Panel({
        renderTo: Ext.getBody(),
        showHeader: false,
        layout: 'border',
        margins: '5 0 0 0',
        height: Ext.getBody().getViewSize().height,
        items: 
        [
            adminTabs,
            {
                region: 'south',
                html: '<font color="red">' 
                    + Ext.util.Format.htmlEncode(htcConfig.locData.AdminCommonSettingsChangeWarning)
                    + '</font>'
                    + (htcConfig.allowedFoldersPaths && htcConfig.allowedFoldersPaths.length > 0 ?
                      '<br/><br/><b>' + Ext.util.Format.htmlEncode(htcConfig.locData.AdminCommonAllowedFoldersPathsTitle) + ':</b></br>'
                    + Ext.util.Format.htmlEncode(htcConfig.allowedFoldersPaths) 
                    : '')
            }
        ],
        tbar: new Ext.Toolbar({
            cls: 'x-panel-header',
            items:
            [
                tbtnGoFileManager = new Ext.Toolbar.Button({
                    text: htcConfig.locData.CommandFileManager,
                    icon: htcConfig.relativePath + 'Images/fileman.png',
                    handler: function() {
                        location.href = "Default.aspx";
                    }
                }),
                { xtype: 'tbfill' },
                tbtnDiagnostics = new Ext.Toolbar.Button({
                    text: htcConfig.locData.CommandDiagnostics, icon: htcConfig.relativePath + 'Images/diagnostics.png',
                    handler: function() { window.open(htcConfig.relativePath + "Diagnostics.aspx"); }
                }),
                tbtnLicenseInfo = new Ext.Toolbar.Button({
                    text: htcConfig.locData.CommandLicenseInfo, icon: htcConfig.relativePath + 'Images/key.png',
                    handler: function() {
                        var message = htcConfig.locData.LicenseTrial;
                        var licInfo = htcConfig.licenseInfo;
                        if(licInfo=='-1')
                            licInfo = "Unlimited";
                        if (htcConfig.licenseInfo) message = String.format(htcConfig.locData.LicensePrompt, licInfo);
                        Ext.Msg.show({
                            title: htcConfig.locData.LicenseTitle,
                            msg: message,
                            icon: Ext.MessageBox.INFORMATION,
                            buttons: Ext.Msg.OK
                        });
                    }
                }),
                tbtnBuyNow = new Ext.Toolbar.Button({
                    text: "Buy now", icon: htcConfig.relativePath + 'Images/buynow.png',
                    handler: function() { window.open("http://www.element-it.com/purchase.aspx#HTTPCommander"); }
                }),
                tbtnLogout = new Ext.Toolbar.Button({
                    xtype: 'button',
                    text: htcConfig.currentUser,
                    tooltip: { text: htcConfig.locData.CommandLogoutHint, title: htcConfig.locData.CommandLogout },
                    icon: htcConfig.relativePath + 'Images/logout.png',
                    handler: function() {
                        location.href = "Logout.aspx";
                    }
                })
            ]
        })
    });

    Ext.EventManager.onWindowResize(function() {
        var el = Ext.getBody();
        view.setHeight(el.getViewSize().height);
        view.setWidth(el.getViewSize().width);
      }, this
    );
});

function navigateHelp() {
    window.open(htcConfig.relativePath + "Manual/adminpanel.html");
}

function identitiesRenderer(value, p, r) {
    result = "";
    Ext.each(value, function(el) {
        if (result) result += ", ";
        result += el.identityName;
    });
    return result;
}

function getDefaultPermission(name) {
    return {
        identityName: name,
        create: true, del: true, rename: true, upload: true, download: true, zipDownload: true,
        zip: true, unzip: true, cut: true, copy: true, listFiles: true, listFolders: true,
        listRestriction: { type: 1, extensions: [] },
        createRestriction: { type: 1, extensions: [] }
    }
}

/* fill the fpPermissions panel of the FolderPermissions dialog */
function fillPermissionData(permission, panel) {
    var form = panel.getForm();
    form.items.each(function(item) { item.suspendEvents(false); });
    form.setValues(permission);
    panel.findById('list-rest').setValue(permission.listRestriction.type);
    panel.findById('list-ext').setValue(permission.listRestriction.extensions.join(','));
    panel.findById('create-rest').setValue(permission.createRestriction.type);
    panel.findById('create-ext').setValue(permission.createRestriction.extensions.join(','));
    form.items.each(function(item) { item.resumeEvents(); });
}

/* save permissions selected on the fpPermissions panel of the FolderPermissions dialog */
function updatePermission() {
    var selectedRecord = gridPerms.getSelectionModel().getSelected();
    if (selectedRecord) {
        var values = fpPermissions.getForm().getValues();
        selectedRecord.data.permission.create = fpPermissions.findById('create').getValue();
        selectedRecord.data.permission.del = fpPermissions.findById('del').getValue();
        selectedRecord.data.permission.rename = fpPermissions.findById('rename').getValue();
        selectedRecord.data.permission.upload = fpPermissions.findById('upload').getValue();
        selectedRecord.data.permission.download = fpPermissions.findById('download').getValue();
        selectedRecord.data.permission.zipDownload = fpPermissions.findById('zipDownload').getValue();
        selectedRecord.data.permission.zip = fpPermissions.findById('zip').getValue();
        selectedRecord.data.permission.unzip = fpPermissions.findById('unzip').getValue();
        selectedRecord.data.permission.cut = fpPermissions.findById('cut').getValue();
        selectedRecord.data.permission.copy = fpPermissions.findById('copy').getValue();
        selectedRecord.data.permission.listFiles = fpPermissions.findById('listFiles').getValue();
        selectedRecord.data.permission.listFolders = fpPermissions.findById('listFolders').getValue();
        selectedRecord.data.permission.modify = fpPermissions.findById('modify').getValue(); // Added by ChessarX, 16.02.2011
        selectedRecord.data.permission.listRestriction.type = parseInt(values.listType);
        selectedRecord.data.permission.createRestriction.type = parseInt(values.createType);

        var listExtensions = fpPermissions.findById('list-ext').getValue();
        var createExtensions = fpPermissions.findById('create-ext').getValue();

        selectedRecord.data.permission.listRestriction.extensions = listExtensions ?  listExtensions.toUpperCase().split(',') : [];
        selectedRecord.data.permission.createRestriction.extensions = createExtensions ? createExtensions.toUpperCase().split(',') : [];
        
        selectedRecord.data.permission.customField = fpPermissions.findById('folders-permissions-custom-field').getValue();    
    }
}

function validateFolderData() {
    var folderName = commonFolderInfo.findById('folder-name').getValue();
    var folderPath = commonFolderInfo.findById('folder-path').getValue();
    if (!folderName) return htcConfig.locData.AdminFoldersEmptyName;
    if (!folderPath) return htcConfig.locData.AdminFoldersEmptyPath;
    if (folderName.indexOf('&') != -1 || folderName.indexOf('\\') != -1 || folderName.indexOf(':') != -1 || folderName.indexOf('/') != -1) return htcConfig.locData.AdminFoldersIncorrectName;

    if (!folderWindow.isEditing) {
        var folderExists = false;
        Ext.each(gridFolders.getStore().data.items, function(item) {
            if (item.data.name.toLowerCase() == folderName.toLowerCase()) folderExists = true;
        });
        if (folderExists) return htcConfig.locData.AdminFoldersAlreadyExists;
    }

    //var regexp = new RegExp('^([A-Za-z]:|\\{2}([-\w]+|((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?))\\(([^"*/:?|<>\\,;[\]+=.\x00-\x20]|\.[.\x20]*[^"*/:?|<>\\,;[\]+=.\x00-\x20])([^"*/:?|<>\\,;[\]+=\x00-\x1F]*[^"*/:?|<>\\,;[\]+=\x00-\x20])?))\\([^"*/:?|<>\\.\x00-\x20]([^"*/:?|<>\\\x00-\x1F]*[^"*/:?|<>\\.\x00-\x20])?\\)*$');
    //if (!regexp.exec(commonFolderInfo.findById('folder-path').getValue())) return "Invalid folder path";
    
    return null;
}

function validateAddUserData() {
    var userName = addUserInfo.findById('add-user-name').getValue();
    if (!userName) 
        return htcConfig.locData.AdminUsersEmptyName;
    var userPassword  = addUserInfo.findById('add-user-password').getValue();
    var userPassword2 = addUserInfo.findById('add-user-password2').getValue();
    if (!userPassword)
        return htcConfig.locData.AdminUsersEmptyPassword;
    if(userPassword != userPassword2)
        return htcConfig.locData.AdminUsersPasswordsNotMatch;

    var userExists = false;
    Ext.each(gridUsers.getStore().data.items, function(item) {
        if (item.data.name.toLowerCase() == userName.toLowerCase()) userExists = true;
    });
    if (userExists) 
        return htcConfig.locData.AdminUsersAlreadyExists;
    return null;
}

function validateEditUserData() {
    var userName = editUserInfo.findById('edit-user-name').getValue();
    if (!userName)
        return htcConfig.locData.AdminUsersEmptyName;

    if (editUserInfo.userName != userName) {
        var userExists = false;
        Ext.each(gridUsers.getStore().data.items, function(item) {
            if (item.data.name.toLowerCase() == userName.toLowerCase()) userExists = true;
        });
        if (userExists) return htcConfig.locData.AdminUsersAlreadyExists;
    }
    return null;
}

function validateSetUserPasswordData() {
    var userPassword  = setUserPasswordInfo.findById('set-user-password-password').getValue();
    var userPassword2 = setUserPasswordInfo.findById('set-user-password-password2').getValue();
    if (!userPassword)
        return htcConfig.locData.AdminUsersEmptyPassword;
    if(userPassword != userPassword2)
        return htcConfig.locData.AdminUsersPasswordsNotMatch;
    return null;
}

function validateGroupData() {
    var groupName = groupInfo.findById('group-name').getValue();
    if (!groupName) return htcConfig.locData.AdminGroupsEmptyName;
    if (!groupWindow.isEditing || (groupWindow.isEditing && groupInfo.groupName != groupName)) {
        var groupExists = false;
        Ext.each(gridGroups.getStore().data.items, function(item) {
            if (item.data.name.toLowerCase() == groupName.toLowerCase()) groupExists = true;
        });
        if (groupExists) return htcConfig.locData.AdminGroupsAlreadyExists;
    }
    return null;
}

function aggregateFolderData() {
    var folder = {};
    folder["name"] = commonFolderInfo.findById('folder-name').getValue();
    folder["path"] = commonFolderInfo.findById('folder-path').getValue();
    folder["description"] = commonFolderInfo.findById('folder-description').getValue();
    folder["customField"] = commonFolderInfo.findById('folder-custom-field').getValue();
    folder["userPerms"] = [];
    folder["groupPerms"] = [];
    Ext.each(gridPerms.getStore().data.items, function(item) {
        if (item.data.type == htcConfig.locData.AdminFoldersUserIdentity) 
            folder["userPerms"].push(item.data.permission);
        else 
            folder["groupPerms"].push(item.data.permission);
    });
    return folder;
}

function aggregateAddUserData() {
    var user = {};
    user["name"] = addUserInfo.findById('add-user-name').getValue();
    user["password"] = addUserInfo.findById('add-user-password').getValue();
    user["email"] = addUserInfo.findById('add-user-email').getValue();
    user["customField"] = addUserInfo.findById('add-user-custom-field').getValue();
    return user;
}

function aggregateEditUserData() {
    var user = {};
    user["origName"] = editUserInfo.userName;
    user["name"] = editUserInfo.findById('edit-user-name').getValue();
    user["email"] = editUserInfo.findById('edit-user-email').getValue();
    user["customField"] = editUserInfo.findById('edit-user-custom-field').getValue();
    return user;
}

function aggregateSetUserPasswordData() {
    var user = {};
    user["name"] = setUserPasswordInfo.findById('set-user-password-name').getValue();
    user["password"] = setUserPasswordInfo.findById('set-user-password-password').getValue();
    return user;
}

function aggregateGroupData() {
    var group = {};
    group["name"] = groupInfo.findById('group-name').getValue();
    group["users"] = [];
    Ext.each(gridMembers.getStore().data.items, function(item) {
        group["users"].push(item.data.name);
    });
    group["origName"] = groupInfo.groupName;
    group["customField"] = groupInfo.findById('group-custom-field').getValue();
    return group;
}

function prepareFolderWindow(folder) {
    fpPermissions.findById('create').setValue(true);
    fpPermissions.findById('del').setValue(true);
    fpPermissions.findById('rename').setValue(true);
    fpPermissions.findById('upload').setValue(true);
    fpPermissions.findById('download').setValue(true);
    fpPermissions.findById('zipDownload').setValue(true);
    fpPermissions.findById('zip').setValue(true);
    fpPermissions.findById('unzip').setValue(true);
    fpPermissions.findById('cut').setValue(true);
    fpPermissions.findById('copy').setValue(true);
    fpPermissions.findById('listFiles').setValue(true);
    fpPermissions.findById('listFolders').setValue(true);
    fpPermissions.findById('modify').setValue(true); // Added by ChessarX, 16.02.2011
    fpPermissions.findById('list-rest').setValue("1");
    fpPermissions.findById('create-rest').setValue("1");
    fpPermissions.findById('list-ext').setValue("");
    fpPermissions.findById('create-ext').setValue("");
    fpPermissions.findById('folders-permissions-custom-field').setValue("");
    fpPermissions.setDisabled(true);
    if (!folder) {
        folderWindow.isEditing = false;
        folderWindow.buttons[0].setText(htcConfig.locData.AdminFoldersAdd);
        commonFolderInfo.findById('folder-name').setDisabled(false);
        commonFolderInfo.findById('folder-name').setValue("");
        commonFolderInfo.findById('folder-path').setValue("");
        commonFolderInfo.findById('folder-description').setValue("");
        commonFolderInfo.findById('folder-custom-field').setValue("");
        gridPerms.getStore().removeAll();
    }
    else {
        folderWindow.isEditing = true;
        folderWindow.buttons[0].setText(htcConfig.locData.AdminFoldersUpdate);
        commonFolderInfo.findById('folder-name').setDisabled(true);
        commonFolderInfo.findById('folder-name').setValue(folder.name);
        commonFolderInfo.findById('folder-path').setValue(folder.path);
        commonFolderInfo.findById('folder-description').setValue(folder.description);
        commonFolderInfo.findById('folder-custom-field').setValue(folder.customField);
        var store = gridPerms.getStore();
        store.removeAll();
        Ext.each(folder.userPerms, function(item) {
            var userRecord = new PermissionRecord({
                name: item.identityName,
                type: htcConfig.locData.AdminFoldersUserIdentity,
                typeId: 'user',
                icon: 'Images/user.png',
                permission: item
            });
            store.add(userRecord);
        });
        Ext.each(folder.groupPerms, function(item) {
            var groupRecord = new PermissionRecord({
                name: item.identityName,
                type: htcConfig.locData.AdminFoldersGroupIdentity,
                typeId: 'group',
                icon: 'Images/group.png',
                permission: item
            });
            store.add(groupRecord);
        });
    }
}

function prepareAddUserWindow(user) {
    addUserInfo.findById('add-user-name').setValue("");
    addUserInfo.findById('add-user-password').setValue("");
    addUserInfo.findById('add-user-password2').setValue("");
    addUserInfo.findById('add-user-email').setValue("");
    addUserInfo.findById('add-user-custom-field').setValue("");
}

function prepareEditUserWindow(user) {
    editUserInfo.userName = user.name;
    editUserInfo.findById('edit-user-name').setValue(user.name);
    editUserInfo.findById('edit-user-email').setValue(user.email);
    editUserInfo.findById('edit-user-custom-field').setValue(user.customField);
}

function prepareSetUserPasswordWindow(user) {
    setUserPasswordInfo.findById('set-user-password-name').setValue(user.name);
    setUserPasswordInfo.findById('set-user-password-password').setValue("");
    setUserPasswordInfo.findById('set-user-password-password2').setValue("");
}

function prepareGroupWindow(group) {
    if (!group) {
        groupWindow.isEditing = false;
        groupWindow.buttons[0].setText(htcConfig.locData.AdminGroupsAdd);
        groupInfo.groupName = '';
        groupInfo.findById('group-name').setDisabled(false);
        groupInfo.findById('group-name').setValue("");
        groupInfo.findById('group-custom-field').setValue("");
        gridMembers.getStore().removeAll();
    }
    else {
        groupWindow.isEditing = true;
        groupWindow.buttons[0].setText(htcConfig.locData.AdminGroupsUpdate);
        groupInfo.groupName = group.name;
        groupInfo.findById('group-name').setDisabled(false);
        groupInfo.findById('group-name').setValue(group.name);
        groupInfo.findById('group-custom-field').setValue(group.customField);
        var store = gridMembers.getStore();
        store.removeAll();
        Ext.each(group.users, function(item) {
            var memberRecord = new MemberRecord({
                name: item,
                icon: 'Images/user.png'
            });
            store.add(memberRecord);
        });
    }
}

/*
    userCallback(btn, userName)
    btn - button that user clicked: 'ok', cancel'
    userName - selected user name if btn is 'ok'
*/
function promptUserName(userCallback) {
    var allUsersStore = new Ext.data.DirectStore({
        directFn: HttpCommander.Admin.GetUsers,
        autoLoad: false,
        fields: [ 'name', 'email', 'icon', 'customField' ]
    });
    var daclUsersStore;
    var showDACL = htcConfig.winAuth;
    var fpPath = '';
    if (showDACL) {
        if (folderWindow && folderWindow.findById('folder-path')) {
            fpPath = folderWindow.findById('folder-path').getValue();
            showDACL = fpPath && fpPath != '';
        } else showDACL = false;
    }    
    var uswItems = [];
    if (showDACL) {
        daclUsersStore = new Ext.data.DirectStore({
            directFn: HttpCommander.Admin.GetUsersFromDACL,
            autoLoad: false,
            baseParams: { folder: fpPath },
            paramOrder: ['folder'],
            fields: [ 'name', 'acl' ]
        });
        uswItems.push({
            id: 'users-all-or-dacl',
            xtype: 'radiogroup',
            vertical: false,
            columns: 2,
            hideLabel: true,
            items:
            [
                {
                    boxLabel: htcConfig.locData.AdminUsersListAll,
                    name: 'rb-auto',
                    id: 'users-all-radio',
                    checked: true,
                    listeners:
                    {
                        check: function (radio, checked) {
                            var combo = Ext.getCmp('userNameCombo');
                            if (combo) combo.bindStore(checked ? allUsersStore : daclUsersStore, false);
                            var daclStr = Ext.getCmp('daclUserString');
                            if (daclStr) {
                                daclStr.setVisible(false);
                                if (!checked) {
                                    var fIndex = daclUsersStore.findBy(function(rec, id) { return rec.get("name").toLowerCase() == combo.getValue().toLowerCase(); });
                                    if (fIndex >= 0) {
                                        daclStr.setText("<span>" + htcConfig.locData.AdminDACLStringLabel + ": <b>" + daclUsersStore.getAt(fIndex).data.acl + "</b></span>", false);
                                        daclStr.setVisible(true);
                                    }
                                }
                            }
                        } 
                    }
                },
                {
                    boxLabel: htcConfig.locData.AdminUsersListDACL,
                    name: 'rb-auto',
                    id: 'users-dacl-radio'
                }                       
            ]
        });
    }  
    uswItems.push({
        id: 'userNameCombo',
        fieldLabel: htcConfig.locData.AdminFoldersUserNamePrompt,
        xtype: 'combo',
        displayField: 'name',
        mode: 'remote',//'local',
        triggerAction: 'all',
        loadingText: htcConfig.locData.ProgressLoading + '...',
        emptyText: htcConfig.locData.AdminFoldersUserNameEmptyText + '...',
        selectOnFocus: true,
        editable: true,
        lazyInit: false,
        store: allUsersStore,
        listeners: {
            'select': function (combo, record, index) {
                var daclStr = Ext.getCmp('daclUserString');
                if (daclStr) {
                    daclStr.setVisible(false);
                    daclStr.setText('');
                    var rg = Ext.getCmp('users-dacl-radio');
                    if (rg && rg.checked) {
                        daclStr.setText("<span>" + htcConfig.locData.AdminDACLStringLabel + ": <b>" + record.data.acl + "</b></span>", false);
                        daclStr.setVisible(true);
                    }
                } 
            },
            change: function (combo, newValue, oldValue) {
                var daclStr = Ext.getCmp('daclUserString');
                if (daclStr) {
                    var rg = Ext.getCmp('users-dacl-radio');
                    daclStr.setVisible(false);
                    daclStr.setText('');
                    if (rg && rg.checked) {
                        var fIndex = daclUsersStore.findBy(function(rec, id) { return rec.get("name").toLowerCase() == newValue.toLowerCase(); });
                        if (fIndex >= 0) {
                            daclStr.setText("<span>" + htcConfig.locData.AdminDACLStringLabel + ": <b>" + daclUsersStore.getAt(fIndex).data.acl + "</b></span>", false);
                            daclStr.setVisible(true);
                        }
                    }
                }
            } 
        }
    });
    if (showDACL) {
        uswItems.push({
            id: 'daclUserString',
            xtype: 'label',
            hidden: true
        });
    }
    var userSelectWindow = new Ext.Window({
        title: htcConfig.locData.AdminFoldersUserNameTitle,
        labelWidth: 100,
        frame: true,
        width: 300,
        border: false,
        modal: true,
        layout: 'form',
        bodyStyle: 'padding: 5px 5px 0 5px',
        buttonAlign: 'center',
        plain: true,
        items: uswItems,
        buttons:
        [
            {
                text: htcConfig.locData.CommonButtonCaptionOK,
                handler: function() {
                    var userName = userSelectWindow.findById('userNameCombo').getValue();
                    if(userName == '') {
                        Ext.Msg.show({
                            title: htcConfig.locData.CommonErrorCaption,
                            msg: htcConfig.locData.AdminFoldersUserNameNotSelected,
                            icon: Ext.MessageBox.ERROR,
                            buttons: Ext.Msg.OK
                        });
                    } else {
                        userSelectWindow.close();
                        userCallback('ok', userName);
                    }
                }
            },
            {
                text: htcConfig.locData.CommonButtonCaptionCancel,
                handler: function() {
                    userSelectWindow.close();
                    userCallback('cancel', '');
                }
            }
        ]
    });
    userSelectWindow.show();
}

/*
    userCallback(btn, groupName)
    btn - button that user clicked: 'ok', cancel'
    groupName - selected group name if btn is 'ok'
*/
function promptGroupName(userCallback) {
    var allGroupsStore = new Ext.data.DirectStore({
        directFn: HttpCommander.Admin.GetGroups,
        autoLoad: false,
        fields: [ 'name', 'users', 'icon', 'customField' ]
    });
    var daclGroupsStore;
    var showDACL = htcConfig.winAuth;
    var fpPath = '';
    if (showDACL) {
        if (folderWindow && folderWindow.findById('folder-path')) {
            fpPath = folderWindow.findById('folder-path').getValue();
            showDACL = fpPath && fpPath != '';
        } else showDACL = false;
    }    
    var gswItems = [];
    if (showDACL) {
        daclGroupsStore = new Ext.data.DirectStore({
            directFn: HttpCommander.Admin.GetGroupsFromDACL,
            autoLoad: false,
            baseParams: { folder: fpPath },
            paramOrder: ['folder'],
            fields: [ 'name', 'acl' ]
        });
        gswItems.push({
            id: 'groups-all-or-dacl',
            xtype: 'radiogroup',
            vertical: false,
            columns: 2,
            hideLabel: true,
            items:
            [
                {
                    boxLabel: htcConfig.locData.AdminGroupsListAll,
                    name: 'rb-auto',
                    id: 'groups-all-radio',
                    checked: true,
                    listeners:
                    {
                        check: function (radio, checked) {
                            var combo = Ext.getCmp('groupNameCombo');
                            if (combo) combo.bindStore(checked ? allGroupsStore : daclGroupsStore, false);
                            var daclStr = Ext.getCmp('daclGroupString');
                            if (daclStr) {
                                daclStr.setVisible(false);
                                if (!checked) {
                                    var fIndex = daclGroupsStore.findBy(function(rec, id) { return rec.get("name").toLowerCase() == combo.getValue().toLowerCase(); });
                                    if (fIndex >= 0) {
                                        daclStr.setText("<span>" + htcConfig.locData.AdminDACLStringLabel + ": <b>" + daclGroupsStore.getAt(fIndex).data.acl + "</b></span>", false);
                                        daclStr.setVisible(true);
                                    }
                                }
                            }
                        } 
                    }
                },
                {
                    boxLabel: htcConfig.locData.AdminGroupsListDACL,
                    name: 'rb-auto',
                    id: 'groups-dacl-radio'
                }                       
            ]
        });
    }  
    gswItems.push({
        id: 'groupNameCombo',
        fieldLabel: htcConfig.locData.AdminFoldersGroupNamePrompt,
        xtype: 'combo',
        lazyInit: false,
        displayField: 'name',
        mode: 'remote', //'local',
        triggerAction: 'all',
        loadingText: htcConfig.locData.ProgressLoading + '...',
        emptyText: htcConfig.locData.AdminFoldersGroupNameEmptyText + '...',
        selectOnFocus: true,
        editable: true,
        store: allGroupsStore,
        listeners: {
            'select': function (combo, record, index) {
                var daclStr = Ext.getCmp('daclGroupString');
                if (daclStr) {
                    daclStr.setVisible(false);
                    daclStr.setText('');
                    var rg = Ext.getCmp('groups-dacl-radio');
                    if (rg && rg.checked) {
                        daclStr.setText("<span>" + htcConfig.locData.AdminDACLStringLabel + ": <b>" + record.data.acl + "</b></span>", false);
                        daclStr.setVisible(true);
                    }
                } 
            },
            change: function (combo, newValue, oldValue) {
                var daclStr = Ext.getCmp('daclGroupString');
                if (daclStr) {
                    var rg = Ext.getCmp('groups-dacl-radio');
                    daclStr.setVisible(false);
                    daclStr.setText('');
                    if (rg && rg.checked) {
                        var fIndex = daclGroupsStore.findBy(function(rec, id) { return rec.get("name").toLowerCase() == newValue.toLowerCase(); });
                        if (fIndex >= 0) {
                            daclStr.setText("<span>" + htcConfig.locData.AdminDACLStringLabel + ": <b>" + daclGroupsStore.getAt(fIndex).data.acl + "</b></span>", false);
                            daclStr.setVisible(true);
                        }
                    }
                }
            } 
        }
    });
    if (showDACL) {
        gswItems.push({
            id: 'daclGroupString',
            xtype: 'label',
            hidden: true
        });
    }
    var groupSelectWindow = new Ext.Window({
        title: htcConfig.locData.AdminFoldersGroupNameTitle,
        labelWidth: 100,
        frame: true,
        width: 300,
        border: false,
        modal: true,
        layout: 'form',
        bodyStyle: 'padding: 5px 5px 0 5px',
        buttonAlign: 'center',
        plain: true,
        items: gswItems,
        buttons:
        [
            {
                text: htcConfig.locData.CommonButtonCaptionOK,
                handler: function() {
                    var groupName = groupSelectWindow.findById('groupNameCombo').getValue();
                    if(groupName == '') {
                        Ext.Msg.show({
                            title: htcConfig.locData.CommonErrorCaption,
                            msg: htcConfig.locData.AdminFoldersGroupNameNotSelected,
                            icon: Ext.MessageBox.ERROR,
                            buttons: Ext.Msg.OK
                        });
                    } else {
                        groupSelectWindow.close();
                        userCallback('ok', groupName);
                    }
                }
            },
            {
                text: htcConfig.locData.CommonButtonCaptionCancel,
                handler: function() {
                    groupSelectWindow.close();
                    userCallback('cancel', '');
                }
            }
        ]
    });
    groupSelectWindow.show();
}

/*
    userCallback(btn, shareName)
    btn - button that user clicked: 'ok', cancel'
    shareName - selected share name if btn is 'ok'
*/
function promptShareName(userCallback) {
    var shareSelectWindow = new Ext.Window({
        title: htcConfig.locData.AdminFoldersShareNameTitle,
        labelWidth: 100,
        frame: true,
        width: 300,
        border: false,
        modal: true,
        layout: 'form',
        bodyStyle: 'padding: 5px 5px 0 5px',
        buttonAlign: 'center',
        plain: true,
        items:
        [
            {
                id: 'shareNameCombo',
                fieldLabel: htcConfig.locData.AdminFoldersShareNameEmptyText,
                xtype: 'combo',
                lazyInit: false,
                displayField: 'path',
                mode: 'remote', //'local',
                triggerAction: 'all',
                tpl: '<tpl for="."><div ext:qtip="{path}" class="x-combo-list-item">{path}</div></tpl>',
                loadingText: htcConfig.locData.ProgressLoading + '...',
                emptyText: htcConfig.locData.AdminFoldersShareNameEmptyText + '...',
                selectOnFocus: true,
                editable: false,
                store: new Ext.data.DirectStore({
                    directFn: HttpCommander.Admin.GetSharedFolders,
                    autoLoad: false,
                    stdTimeout: Ext.Ajax.timeout,
                    fields: [ 'path' ],
                    listeners: {
                        beforeload: function (ds, op) {
                            ds.stdTimeout = Ext.Ajax.timeout;
                            Ext.Ajax.timeout = ajaxRequestTimeout;
                        },
                        load: function(ds, records, op) {
                            Ext.Ajax.timeout = ds.stdTimeout;
                        },
                        exception: function(misc) {
                            if (this && this.stdTimeout)
                                Ext.Ajax.timeout = this.stdTimeout;
                            else
                                Ext.Ajax.timeout = 30000;
                        }
                    }
                }),
                listeners: {
                    'select': function (combo, record, index) {
                        Ext.QuickTips.getQuickTip().register({
                            target: this.el,
                            text: record.data.path
                        });
                    }
                }
            }
        ],
        listeners: {
            show: function(window) {
                var comboField = window.findById('shareNameCombo');
                if (comboField) {
                    var val = comboField.getValue();
                    if (val && val != '') {
                        Ext.QuickTips.getQuickTip().register({
                            target: comboField.el,
                            text: val
                        });
                    } else {
                        Ext.QuickTips.getQuickTip().unregister(comboField.el);
                    }
                }
            }
        },
        buttons:
        [
            {
                text: htcConfig.locData.CommonButtonCaptionOK,
                disabled: showListForAllowedFolders, // ???
                handler: function() {
                    var shareName = shareSelectWindow.findById('shareNameCombo').getValue();
                    if(shareName == '') {
                        Ext.Msg.show({
                            title: htcConfig.locData.CommonErrorCaption,
                            msg: htcConfig.locData.AdminFoldersShareNameNotSelected,
                            icon: Ext.MessageBox.ERROR,
                            buttons: Ext.Msg.OK
                        });
                    } else {
                        shareSelectWindow.close();
                        userCallback('ok', shareName);
                    }
                }
            },
            {
                text: htcConfig.locData.CommonButtonCaptionCancel,
                handler: function() {
                    shareSelectWindow.close();
                    userCallback('cancel', '');
                }
            }
        ]
    });
    shareSelectWindow.show();
}

function dateRendererLocal(val, cell, rec) {
    return val.toLocaleString();
}
