Ext.ns('HttpCommander');
//Define new component for toggle button
Ext.ToggleActionButton = Ext.extend(Ext.Button, {
    listeners: {
        tap: function(self, e) {
            this.setPressed(!this.pressed);
        },
        render: function(self) {
            this.setPressed(this.pressed);
        }
    },
    setPressed: function(newVal) {
        this.pressed = newVal;
        if (!this.pressed)
            this.removeCls('x-button-pressed');
        else
            this.addCls('x-button-pressed');
    }
});

Ext.ComponentMgr.registerType('toggleactionbutton', Ext.ToggleActionButton);


Ext.LinkButton = Ext.extend(Ext.Button, {
    href: '#',
    target: '_blank',
        
    setHref: function(href) {
        this.href = href; 
        if(this.text)       
            this.setText(this.text);
    },
    setText: function(text) {
        var me = this;
                       
        Ext.LinkButton.superclass.setText.call(me, text);
        
        var lnk = '<a href="'+this.href+'" target="'+this.target+'" onClick="'+(this.href=='#'?'javascript: return false;':'')+'">'+this.text+'</a>';
        if(me.textEl)
            me.textEl.setHTML(lnk);
        return me;
    }
});
Ext.ComponentMgr.registerType('linkbutton', Ext.LinkButton);


//Main class for all methods and objects
HttpCommander.Main = {
    handleErrors: true,
    init: function() {
        try {
            this.globalLoadMask = new Ext.LoadMask(Ext.getBody(), {
                msg: htcConfig.locData.ProgressLoading + "..."
            });         
        }
        catch (e) {
            this.ProcessScriptError(e);
        }
        try {
            this.itemToSelect = null;
            // Array of main grid fields.
            this.gridStoreFields =
            [
                { name: 'id', type: 'string' },
                { name: 'name', type: 'string' },
                { name: 'path', type: 'string' },
                { name: 'icon', type: 'string' },
                { name: 'rowtype', type: 'string' }
            ];
            if (htcConfig.avaliableColumnsInList.size)
                this.gridStoreFields.push({ name: 'size', type: 'string' });
            if (htcConfig.avaliableColumnsInList.type)
                this.gridStoreFields.push({ name: 'type', type: 'string' });
            if (htcConfig.avaliableColumnsInList.datemodified)
                this.gridStoreFields.push({ name: 'datemodified', type: 'date', dateFormat: 'c' });
            if (htcConfig.avaliableColumnsInList.datecreated)
                this.gridStoreFields.push({ name: 'datecreated', type: 'date', dateFormat: 'c' });
            if (htcConfig.avaliableColumnsInList.dateaccessed)
                this.gridStoreFields.push({ name: 'dateaccessed', type: 'date', dateFormat: 'c' });
            if (htcConfig.metaDataTitles)
                Ext.each(htcConfig.metaDataTitles, function(el) {
                    var visible = false;
                    eval("if (htcConfig.avaliableColumnsInList." + el.toLowerCase() + " != undefined) visible = htcConfig.avaliableColumnsInList." + el.toLowerCase() + ";");
                    if (visible)
                        HttpCommander.Main.gridStoreFields.push({ name: el.toLowerCase(), type: 'string' });
                });

            this.itemInfoStoreFields =
            [                
                { name: 'name', type: 'string' },
                { name: 'path', type: 'string' },
                { name: 'icon', type: 'string' },
                { name: 'rowtype', type: 'string' },
                { name: 'size', type: 'string' },                
                { name: 'type', type: 'string' },
                { name: 'datemodified', type: 'date', dateFormat: 'timestamp'},
                { name: 'datecreated', type: 'date', dateFormat: 'timestamp' },
                { name: 'dateaccessed', type: 'date', dateFormat: 'timestamp' },
                
                { name: 'sizeFormatted', type: 'string' },
                { name: 'datemodifiedFormatted', type: 'string'},
                { name: 'datecreatedFormatted', type: 'string'},
                { name: 'dateaccessedFormatted', type: 'string'}
            ];
            if (htcConfig.metaDataTitles)
                Ext.each(htcConfig.metaDataTitles, function(el) {
                    var visible = false;
                    eval("if (htcConfig.avaliableColumnsInList." + el.toLowerCase() + " != undefined) visible = htcConfig.avaliableColumnsInList." + el.toLowerCase() + ";");
                    if (visible)
                        HttpCommander.Main.itemInfoStoreFields.push({ name: el.toLowerCase(), type: 'string' });
                });
        }
        catch (e) { this.ProcessScriptError(e); };

        try
        {
            Ext.regModel('Files', {
                fields: this.gridStoreFields
            });

            Ext.regModel('FileInfo', {
                fields: this.itemInfoStoreFields,
                formatFields : function (){                
                    this.set('sizeFormatted', HttpCommander.Main.sizeRenderer(this.get('size')));
                    var d = new Date(this.get('datemodified'));
                    this.set('datemodifiedFormatted', d.toLocaleString());
                    d = new Date(this.get('datecreated'));
                    this.set('datecreatedFormatted', d.toLocaleString());
                    d = new Date(this.get('dateaccessed'));
                    this.set('dateaccessedFormatted', d.toLocaleString());
                    
                }          
            });
        }
        catch (e) { this.ProcessScriptError(e); };

        try {
            this.gridStore = new Ext.data.DirectStore({
                model: "Files",    
                loadMask: this.globalLoadMask,     
                autoLoad: true,
                transId: 1,
                url: HttpCommander.Remote.GridHandler.url,
                directAction: 'Grid',
                directMethod: 'Load',
                paramOrder: ['sort', 'dir', 'path'],
                params: {
                    sort: 'name',
                    dir: 'ASC',
                    path: 'root'
                },
                fields: this.gridStoreFields,
                listeners: {
                    load: function(store, records, options) {
                        var curFolder = HttpCommander.Main.getCurrentFolder();
                        if (!store.proxy.reader.jsonData.success) {
                            Ext.Msg.show({
                                title: htcConfig.locData.CommonErrorCaption,
                                msg: store.proxy.reader.jsonData.msg,
                                icon: Ext.MessageBox.ERROR,
                                buttons: Ext.Msg.OK
                            });
                            HttpCommander.Main.openGridFolder(HttpCommander.Main.pathUp(HttpCommander.Main.getCurrentFolder()));
                        }

                        htcConfig.currentPerms = eval("(" + store.proxy.reader.jsonData.permissions + ")");
                        try {
                            HttpCommander.Main.ui.fileList.scroller.scrollTo({ x: 0, y: 0 });

                        }
                        catch (e) { }
                        if(HttpCommander.Main.ui)
                            HttpCommander.Main.ui.folderChange(curFolder);
                    }
                }
            });

            this.itemInfoStore = new Ext.data.DirectStore({
                model: "FileInfo",                
                autoLoad: false,
                loadMask: this.globalLoadMask,
                transId: 100,
                url: HttpCommander.Remote.CommonHandler.url,                
                directAction: 'Common',
                directMethod: 'GetInfo',
                paramOrder: ['data'],                
                params: {
                    data: {}
                },
                fields: this.itemInfoStoreFields,
                proxy: {
                    type: 'direct',                    
                    writer: 'json',
                    reader: {
                        type: 'direct',
                        root: null,
                        totalCount: null,
                    }
                },
                listeners: {
                    load: function(store, records, options) {
                        HttpCommander.Main.globalLoadMask.hide();
                        //HttpCommander.Main.ui.fileDetailsForm.loadModel(store.proxy.reader.jsonData); 
                        var fi = Ext.ModelMgr.create(store.proxy.reader.jsonData,'FileInfo');
                        fi.formatFields();
                        
                        //enable download button in action bar
                        /*HttpCommander.Main.ui.actionBar.configureDownloadButton("file", fi.data.name);  
                        HttpCommander.Main.ui.actionBar.configureDeleteButton("file", fi.data.name);
                        */
                        HttpCommander.Main.ui.actionBar.configureForSelection("file", fi.data.name);
                        HttpCommander.Main.ui.fileDetailsForm.load(fi);
                        HttpCommander.Main.ui.setActiveItem('fileDetailsForm', { type: 'slide', direction: 'left' }); ;
                        HttpCommander.Main.ui.actionBar.configureForPanel('fileDetailsForm');
                    }
                },
                loadFileInfo: function(name, type) {                    
                    this.params.data['type'] = type;
                    this.params.data['name'] = name;
                    this.params.data['path'] = HttpCommander.Main.getCurrentFolder();
                    this.load();
                }
            });
        }
        catch (e) { this.ProcessScriptError(e); };
        
        try{
            this.directMethod = new Ext.data.DirectStore({                
                autoLoad: false,                
                transId: 200,
                url: HttpCommander.Remote.CommonHandler.url,                
                directAction: 'Common',
                directMethod: 'GetInfo',
                paramOrder: ['data'],                
                params: {
                    data: {}
                },
                fields: this.itemInfoStoreFields,
                proxy: {
                    type: 'direct',                    
                    writer: 'json',
                    reader: {
                        type: 'direct',
                        root: null,
                        totalCount: null
                    }
                },
                listeners: {
                    load: function(store, records, options) {
                        HttpCommander.Main.globalLoadMask.hide();                        
                        //store.proxy.reader.jsonData
                        if (Ext.isFunction(this.cb)) {
                                this.cb.call(this, store.proxy.reader.jsonData, options);
                        }                       
                    }
                },
                callMethod: function(action, method, params, callback) {                    
                    HttpCommander.Main.globalLoadMask.show();
                    this.cb = callback;
                    this.directAction = action;
                    this.directMethod = method;
                    this.params.data = params;                   
                    //this.params.data['path'] = HttpCommander.Main.getCurrentFolder();
                    this.load();
                }
            });
        }
        catch (e) { this.ProcessScriptError(e); };
              
        //this.globalLoadMask.bindStore(this.gridStore, true);
        try{       
            this.ui = new HttpCommander.MainPanel();
        }
        catch (e) { this.ProcessScriptError(e); };
        
    },

    /*
    Action on item tap 
    */
    gridRowAction: function(record, index) {
        var curFolder = this.getCurrentFolder();
        if (record.data.rowtype == "folder" || record.data.rowtype == "rootfolder") {
            var newPath = this.pathAppendFolder(curFolder, record.data.name);
            this.openGridFolder(newPath);
        }
        else if (record.data.rowtype == "uplink") {
            HttpCommander.Main.itemToSelect = HttpCommander.Main.getCurrentFolderName();
            var newPath = this.pathUp(curFolder);
            this.openGridFolder(newPath);
        }
        else {
            //this.downloadFile(record, curFolder);
        }
    },

    /*
    ShowFile info
    */
    gridRowAction: function(record, index) {
        var curFolder = this.getCurrentFolder();
        if (record.data.rowtype == "folder" || record.data.rowtype == "rootfolder") {
            var newPath = this.pathAppendFolder(curFolder, record.data.name);
            this.openGridFolder(newPath);
        }
        else if (record.data.rowtype == "uplink") {
            HttpCommander.Main.itemToSelect = HttpCommander.Main.getCurrentFolderName();
            var newPath = this.pathUp(curFolder);
            this.openGridFolder(newPath);
        }
        else {
            //this.downloadFile(record, curFolder);
        }
    },

    /*
    If some error in JS occured
    */
    ProcessScriptError: function(e) {
        if (HttpCommander.Main.handleErrors) {
            var msg = "Script error occured. ";
            if (e != undefined && e.message != undefined && e.name != undefined)
                msg += "Message:" + e.message + " Name: " + e.name;
            window.alert(msg);
        }
        else
            throw e;
    },

    /* concatenate path + name producing new path */
    pathAppendFolder: function(path, name) {
        if (path.toLowerCase() == "root")
            return name;
        if (path.length > 0 && path[path.length - 1] != '/')
            path += '/';
        return path + name;
    },

    /* one level up, truncate the last folder */
    pathUp: function(path) {
        var i = path.lastIndexOf('/');
        if (i < 0)
            return "root";
        else
            return path.substr(0, i);
    },

    /*
    Return name of current folder.
    */
    getCurrentFolderName: function() {
        var path = this.getCurrentFolder();
        var i = path.lastIndexOf('/');
        if (i < 0)
            return path;
        else
            return path.substr(i + 1);
    },

    // folder opened in HttpCommander
    getCurrentFolder: function() {
        return this.gridStore.params.path;
    },

    //Open cpecified folder in grid (list)
    openGridFolder: function(path) {
        this.gridStore.params.path = path;
        this.gridStore.load();
    },

    /*
    Download selected file
    */
    downloadFile: function(name, path, windowOpen) {
        if (htcConfig.currentPerms && htcConfig.currentPerms.download)            
        {
            var fileUrl = htcConfig.relativePath + "Handlers/Download.ashx?action=download&file=" + encodeURIComponent(path) + "/" + encodeURIComponent(name);
            if(!window.open(fileUrl))
                location.href = fileUrl;            
        }       
    },
    setDownloadLink: function(btn, name, path) {
        if (htcConfig.currentPerms && htcConfig.currentPerms.download)
            btn.setHref(name =='#'? name : htcConfig.relativePath + "Handlers/Download.ashx?action=download&file=" + encodeURIComponent(path) + "/" + encodeURIComponent(name));
            
    },
    
    sizeRenderer: function (size) {
        if (size == "") return "";
        else if (size < 1024) {
            return size + " bytes";
        } else if (size < 1048576) {
            return (Math.round(((size * 10) / 1024)) / 10) + " KB";
        } else if (size < 1073741824) {
            return (Math.round(((size * 10) / 1048576)) / 10) + " MB";
        } else {
            return (Math.round(((size * 10) / 1073741824)) / 10) + " GB";
        }
    },
    stopUploadFiles: function(fp){
        var upload_frame = Ext.getBody().child('iframe.x-hidden');
        fp.setUploadInProcess(false);
        if (upload_frame) {
            if (/MSIE (\d+\.\d+);/.test(navigator.userAgent))
                window.frames[upload_frame.id].window.document.execCommand('Stop');
            else
                window.frames[upload_frame.id].window.stop();                     
            var curFolder = this.getCurrentFolder();
            HttpCommander.Main.openGridFolder(curFolder);
            //showBalloon(htcConfig.locData.BalloonAbortFilesUploaded);
        }
    },
    uploadFiles: function (fp, uploadFolderPath) {        
       /* Ext.Msg.show({
            title: htcConfig.locData.UploadProgressTitle,
            msg: "<img src='" + htcConfig.relativePath + "Images/ajax-loader.gif' class='filetypeimage'>&nbsp;" + htcConfig.locData.UploadInProgress + "...",
            closable: false,
            modal: true,
            width: 220
        });*/
        fp.el.dom.enctype='multipart/form-data';
        fp.setUploadInProcess(true);        
        fp.doFormUpload(fp, fp.params, {
            url: htcConfig.relativePath + 'Handlers/Upload.ashx?path=' + uploadFolderPath,
           
            success: function (action, form) {
                fp.setUploadInProcess(false);                                      
                try{
                    action.result = Ext.decode(action.responseText);
                    var balloonText = "";
                    if(action.result.success !== true)
                    {
                        balloonText = action.result.msg;
                        Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, action.result.msg);                        
                    }
                    else
                    {
                        try{
                            var path = fp.items.get('inputFileField').getValue();
                            var i = path.lastIndexOf('/');
                            if (i < 0)
                                i = path.lastIndexOf('\\');
                            if (i < 0)
                                HttpCommander.Main.itemToSelect = path;
                            else
                                HttpCommander.Main.itemToSelect = path.substr(i + 1);
                             
                        }        
                        catch(e){}
                        var balloonText = Ext.util.Format.format(htcConfig.locData.BalloonFilesUploaded, action.result.filesSaved);
                        if(action.result.filesRejected > 0) 
                            balloonText += Ext.util.Format.format(htcConfig.locData.BalloonFilesNotUploaded, action.result.filesRejected) + ". " + action.result.msg;
                    }
                    fp.items.get('uploadStatusLabel').labelEl.dom.innerHTML = "<span><br/>"+balloonText+"</span>";
                  
                }
                catch(e){ 
                    alert(e);
                }          
                HttpCommander.Main.openGridFolder(uploadFolderPath);                     
            },
            failure: function (action, form) {
                fp.setUploadInProcess(false);                
                Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, action.result.msg);
            }
        });        
    },
    /*
        Return prepared object for ajax request 
        get data about selected files from list . Should get also from info panel
    */
    createSelectedSet: function(grid, curFolder) {
        if(grid.getSelectionModel().selected)
        {
            var selectedRecords = grid.getSelectionModel().selected.items;
            var fileArray = new Array();
            var folderArray = new Array();
            Ext.each(selectedRecords, function (el) {
                if (el.data.rowtype == "folder") folderArray.push(el.data.name);
                else if (el.data.rowtype == "file") fileArray.push(el.data.name);
            });
            var selectedSet = {};
            selectedSet["path"] = curFolder;
            selectedSet["files"] = eval(Ext.util.JSON.encode(fileArray));
            selectedSet["folders"] = eval(Ext.util.JSON.encode(folderArray));
            selectedSet["filesCount"] = fileArray.length;
            selectedSet["foldersCount"] = folderArray.length;
            return selectedSet;
         }
         return newArray();
    },

    createSelectedFilesSet: function(grid) {
        if(grid.getSelectionModel().selected)
        {
            var selectedRecords = grid.getSelectionModel().selected.items;
            var fileArray = new Array();
            Ext.each(selectedRecords, function (el) {
                if (el.data.rowtype == "file") fileArray.push(el.data.name);
            });
            return eval(Ext.util.JSON.encode(fileArray));
        }
        return newArray();
    }
};


//main panel withh all UI elements
HttpCommander.MainPanel = Ext.extend(Ext.Panel, {
    fullscreen: true,
    loadMask: HttpCommander.Main.globalLoadMask,
    width: undefined,
    height: undefined,
    layout: 'card',
    cardSwitchAnimation: 'slide',
    initComponent: function() {
        //Template for list item
        this.listItemTpl = new Ext.XTemplate(
                '<img src="{[htcConfig.relativePath]} {icon}" class="filetypeimage">',
                '{name}'
            );
       

        //Base configuration parameters  for file list
        this.fileList = new Ext.List({
            id: 'fileList',
            panel: this,
            itemTpl: this.listItemTpl,
            allowDeselect: true,
            singleSelect: true,
            grouped: false,
            indexBar: true,
            store: HttpCommander.Main.gridStore,
            clearSelectionOnDeactivate: false,            
            listeners:
                {
                    selectionChange: function(list, records) {
                        var selModel = this.panel.fileList.getSelectionModel();
                        var removeFromSelection = null;
                        if (selModel.getCount() > 0)
                            Ext.each(selModel.selected.items,
                                function(r) {
                                    if (r.data.rowtype == 'uplink') {
                                        removeFromSelection = r;
                                        return;
                                    }
                                }
                            );
                        if (removeFromSelection) {
                            //selModel.selected.items.shift(removeFromSelection);
                            selModel.deselect([removeFromSelection]);
                        }
                        //if(this.panel.getActiveItem().id == 'fileList')
                        this.panel.actionBar.configureForSelection();
                    },
                    itemTap: function(dataView, index, item, e) {
                        var actionAllowed = true;
                        if (!this.panel.actionBar != null && this.panel.actionBar.items.get('multiselect') != null && this.panel.actionBar.items.get('multiselect').pressed)
                            actionAllowed = false;
                        if (actionAllowed) {
                            var record = HttpCommander.Main.gridStore.getAt(index);
                            HttpCommander.Main.gridRowAction(record, index);
                        }
                    },
                    refresh: function(self) {
                        try {
                            /*
                            *   Code to disable disclosure element for non-files
                            */
                            var nodes = this.getNodes();
                            var record = null;
                            for (var i = 0; i < nodes.length; i++) {
                                record = this.getRecord(nodes[i]);
                                if (record.data.rowtype != 'file')
                                    Ext.get(nodes[i]).child("div.x-list-disclosure").setVisible(false);
                            }
                        }
                        catch (e)
                        { }
                    },
                    activate: function(){
                        this.panel.actionBar.configureForPanel(this.id);
                    }
                },
            onItemDisclosure:
                    function(record, btn, index) {
                        HttpCommander.Main.globalLoadMask.show();
                        HttpCommander.Main.itemInfoStore.loadFileInfo(record.data.name, 'file');                                                
                    }
        });


        //Back button
        this.backButton = new Ext.Button({
            text: htcConfig.locData.CommandBack,
            ui: 'back',
            handler:  this.backButtonHandler,
            hidden: true,
            scope: this
        });

         //Logout button
        this.settingsButton = new Ext.Button({
            ui: 'round',
            text: htcConfig.locData.CommandSettings,
            scope: this,
            handler: function(btn, event) {
                this.settingsMenu.setCentered(false);
                //this.settingsMenu.setTitle('Settings');
                this.settingsMenu.showBy(btn);
            }
        });
        
        //Logout button
        this.logoutButton = new Ext.Button({
           // ui: 'round',
            text: htcConfig.locData.CommandLogout,
            handler: function() {
                location.href = htcConfig.relativePath + "Logout.aspx";
            }
        });
        
        //Button to change UI to standard
        this.standardUIButton = new Ext.Button({
            //ui: 'dark-round',
            text: htcConfig.locData.CommandStandardView,
            handler: function() {
                location.href = htcConfig.relativePath + "Default.aspx?Mobile=standard";
            }
        });
        
        this.settingsMenu = new Ext.form.FormPanel({
            floating: true,
            ui: 'dark',
            modal: true,
            centered: false,
            cls: 'touchContextMenu',                 
            scroll: 'vertical',
            defaults: {
                    ui: 'round'
                },
            items: [
                    this.standardUIButton,  
                    this.logoutButton                               
            ]
        });
      

        //Combine buttons for navigation panel        
        this.navigationButtons = [this.backButton, { xtype: 'spacer' }, this.settingsButton];
        //Navigation bar displayed (docked) at the top of UI
        this.navigationBar = new Ext.Toolbar({
            ui: 'dark',
            dock: 'top',
            title: htcConfig.locData.CommonMainTitle,
            items: this.navigationButtons
        });

        var actionButtonHandler = function(button, event) {
            var curFolder = HttpCommander.Main.getCurrentFolder();
            var selModel = this.fileList.getSelectionModel();
            switch (button.id) {
                case 'download':                
                case 'downloadNewWindow':
                    switch (this.getActiveItem().id) {
                        case 'fileList':
                            if (selModel.getCount() == 1 && selModel.selected.items[0].data.rowtype == "file") {
                                var selectedRecord = selModel.selected.items[0];
                                HttpCommander.Main.downloadFile(selectedRecord.data.name, curFolder, button.id == 'downloadNewWindow');
                            }
                            break;
                        case 'fileDetailsForm':
                            HttpCommander.Main.downloadFile(this.fileDetailsForm.record.data.name, curFolder, button.id == 'downloadNewWindow');
                            break;
                    }
                    break;
                case 'delete':
                    var selectedSet = HttpCommander.Main.createSelectedSet(this.fileList, curFolder);
                    var message;
                    var itemName;
                    if (selectedSet.filesCount == 0 && selectedSet.foldersCount == 1) itemName = selectedSet.folders[0];
                    if (selectedSet.foldersCount == 0 && selectedSet.filesCount == 1) itemName = selectedSet.files[0];
                    if (itemName != undefined) message = Ext.util.Format.format(htcConfig.locData.CommonDeleteOnePrompt, itemName);
                    else message = Ext.util.Format.format(htcConfig.locData.CommonDeleteManyPrompt, selectedSet.filesCount + selectedSet.foldersCount);
                    Ext.Msg.show({
                        title: htcConfig.locData.CommonConfirmCaption,
                        msg: message,                        
                        buttons: Ext.MessageBox.YESNO,
                        icon: Ext.MessageBox.QUESTION,
                        fn: function (result) {
                            if (result == "yes") {
                                var curFolder = HttpCommander.Main.getCurrentFolder();                                
                                HttpCommander.Main.directMethod.callMethod('Common', 'Delete', selectedSet, function (data, trans) {                                    
                                    if (data == undefined) {
                                        Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, trans.message);
                                        return;
                                    }
                                    var tip = "";
                                    if (data.filesDeleted > 0) tip += Ext.util.Format.format(htcConfig.locData.BalloonFilesDeleted, data.filesDeleted);
                                    if (data.foldersDeleted > 0) {
                                        if (tip != "") tip += "<br>";
                                        tip += Ext.util.Format.format(htcConfig.locData.BalloonFoldersDeleted, data.foldersDeleted);
                                    }
                                    var filesFailed = selectedSet.filesCount - data.filesDeleted;
                                    if (filesFailed > 0) {
                                        if (tip != "") tip += "<br>";
                                        tip += Ext.util.Format.format(htcConfig.locData.BalloonFilesFailed, filesFailed);
                                    }
                                    var foldersFailed = selectedSet.foldersCount - data.foldersDeleted;
                                    if (foldersFailed > 0) {
                                        if (tip != "") tip += "<br>";
                                        tip += Ext.util.Format.format(htcConfig.locData.BalloonFoldersFailed, foldersFailed);
                                    }

                                    if (data.status != "success") {
                                        Ext.Msg.alert(htcConfig.locData.CommonErrorCaption, data.message);
                                    }
                                    else 
                                    {
                                        if(HttpCommander.Main.ui.getActiveItem().id == 'fileDetailsForm')   
                                            HttpCommander.Main.ui.backButtonHandler();
                                        HttpCommander.Main.openGridFolder(curFolder);
                                    }
                                    //showBalloon(tip);                                                                       
                                });
                            }
                        }
                    });
                    break;
                case 'upload':
                    this.showUploadWindow();
                    break;
                case 'multiselect':
                    //reset selection to the last item when user change from multi to single selection
                    if (button.pressed && selModel.getCount() >= 1) {
                        selModel.select(selModel.selected.items[selModel.getCount() - 1]);
                    }
                    selModel.setSelectionMode(button.pressed ? 'SINGLE' : 'SIMPLE');
                    break;
            }
        };

        this.actionButtons = [
                    {
                        id: 'download',
                        iconCls: 'download',                       
                        text: htcConfig.locData.CommandDownload
                    },
                   /* { 
                        id: 'delete',
                        text: htcConfig.locData.CommandDelete,
                        iconCls: 'delete_black1'
                    },*/
                    /*{
                        id: 'downloadNewWindow',
                        iconCls: 'doc_down',                       
                        text: htcConfig.locData.CommandDownloadNewWindow
                    },*/
                    /*{
                        xtype: 'linkbutton',
                        id: 'downloadHref',
                        //iconCls: 'download',                                                
                        href: '#',
                        //ui: 'round',
                        text: htcConfig.locData.CommandDownload
                    }, */                  
                    { xtype: 'spacer' },
                    {
                        id: 'upload',
                        iconCls: 'upload2',
                        text: htcConfig.locData.CommandUpload
                    },
                    /*{
                    xtype: 'toggleactionbutton',
                    id: 'multiselect',
                    pressed: false,
                    iconCls: 'docs2',
                    text: 'multi-select'                        
                    }*/
        ];
        
        this.actionBar = new Ext.Toolbar({
            panel: this,
            dock: 'bottom',
            scroll: 'horizontal',
            ui: 'dark',
            hidden: false,
            cls: 'nav-bar',
            layout: {
                pack: 'center'
            },
            defaults: {
                xtype: 'button',
                handler: actionButtonHandler,
                iconMask: true,
                scope: this,
                ui: 'plain'
            },
            items: this.actionButtons,

            configureForFolderChange: function() {
                if(this.panel.getActiveItem().id == 'fileList')
                    this.configureForSelection();
                /*var downloadVisible = htcConfig.currentPerms && htcConfig.currentPerms.download;
                var uploadVisible = !Ext.is.iOS && htcConfig.currentPerms && htcConfig.currentPerms.upload;
                if(this.items.get('download'))
                    this.items.get('download').setVisible(downloadVisible);
                if(this.items.get('downloadNewWindow'))
                    this.items.get('downloadNewWindow').setVisible(downloadVisible);
                if(this.items.get('downloadHref'))
                    this.items.get('downloadHref').setVisible(downloadVisible);
                if(this.items.get('upload'))
                    this.items.get('upload').setVisible(uploadVisible);*/
            },
            
            configureForPanel: function(id){
                switch(id){
                    case 'fileList':
                        this.configureForFolderChange();
                        break;
                    case 'fileDetailsForm':
                        this.items.get('upload').setVisible(false);                        
                        break;
                }
                
            },
            
            configureForSelection: function(sel, selName) {                
                    var selModel = this.panel.fileList.getSelectionModel();
                    var selType = "set";
                    var selFiles = 0;
                    if(!sel)
                    {
                        if (HttpCommander.Main.getCurrentFolder() == null)
                            selType = "empty";
                        else {
                            if (selModel.getCount() == 0) selType = "none";
                            else if (selModel.getCount() == 1) {
                                selType = selModel.selected.items[0].data.rowtype;
                                if (selType == "file") selFiles++;
                            } else Ext.each(selModel.selected.items, function(r) { if (r.data.rowtype == 'file') selFiles++; }); // Added by Chessar7, 31.01.2011
                        }   
                    }
                    else    
                        selType = sel;
                    var name = selName ? selName: (selType=="file" ? selModel.selected.items[0].data.name : "#");
                    this.configureDownloadButton(selType, name);
                    this.configureDeleteButton(selType);
                    this.configureUploadButton(selType);
            },
            configureUploadButton: function(selType){
                 var uploadVisible = !Ext.is.iOS && htcConfig.currentPerms && htcConfig.currentPerms.upload;
                 if(this.items.get('upload'))
                    this.items.get('upload').setVisible(uploadVisible);
            },
            configureDeleteButton: function(selType){
                var deleteVisible = htcConfig.currentPerms && htcConfig.currentPerms.del;
                var deleteEnabled = selType != "empty" && selType != "none";
                if(this.items.get('delete'))
                {
                    this.items.get('delete').setVisible(deleteVisible);
                    this.items.get('delete').setDisabled(!deleteEnabled);                
                }
            },
            configureDownloadButton: function(selType, name){
                var downloadVisible = htcConfig.currentPerms && htcConfig.currentPerms.download;
                var downloadEnabled = selType == "file"; //selType != "empty" && selType != "none";
                var downloadText = htcConfig.locData.CommandDownload; // + (selType == "set" ? '...' : '');

                //this.items.get('download').setVisible(downloadVisible);// && downloadEnabled);
                if(this.items.get('download'))
                {
                    this.items.get('download').setVisible(downloadVisible);
                    this.items.get('download').setDisabled(!downloadVisible || !downloadEnabled);
                    this.items.get('download').setText(downloadText);
                }
                if(this.items.get('downloadNewWindow'))
                {
                    this.items.get('downloadNewWindow').setVisible(downloadVisible);
                    this.items.get('downloadNewWindow').setDisabled(!downloadVisible || !downloadEnabled);
                    this.items.get('downloadNewWindow').setText(htcConfig.locData.CommandDownloadNewWindow);
                }
                if(this.items.get('downloadHref'))
                {
                    this.items.get('downloadHref').setVisible(downloadVisible);
                    this.items.get('downloadHref').setDisabled(!downloadVisible || !downloadEnabled);
                    this.items.get('downloadHref').setText(downloadText);
                }
                if(this.items.get('downloadHref'))
                    if (selType == "file")
                        HttpCommander.Main.setDownloadLink(this.items.get('downloadHref'), name, HttpCommander.Main.getCurrentFolder());
                    else    
                        HttpCommander.Main.setDownloadLink(this.items.get('downloadHref'), '#');
                   
                
            }
        });

        //Disable Upload button for IOS devices
        if(Ext.is.iOS)
            this.actionBar.items.get('upload').setVisible(false);
            
        this.dockedItems = [this.navigationBar, this.actionBar];

        this.fileDetailsForm = new Ext.form.FormPanel({
            id: 'fileDetailsForm',
            scroll: 'vertical',
            standardSubmit: false, 
            scope:this,          
            items: [
                {
                    xtype: 'fieldset',
                    defaults: {
                        xtype: 'textfield',
                        required: false,
                        style: 'font-size:0.9em;',
                        labelAlign: 'left',
                        labelWidth: '40%',                       
                        layout: 'vbox'
                        //autoHeight:true
                    },
                    items: [
                    {
                        xtype : 'textareafield',
                        /*defaultAutoCreate : {                            
                            style:"width:100px;height:60px;",
                            autocomplete: "on"
                        },*/
                        name: 'name',
                        label: htcConfig.locData.FileGridNameColumn,                        
                        grow: true
                    }, {
                        name: 'type',
                        label: htcConfig.locData.FileGridTypeColumn
                    }, /* {
                        xtype : 'textareafield',
                        name  : 'path',
                        label : 'Full Path',                        
                        maxRows : 2
                    },*/{
                    name: 'sizeFormatted',
                    label: htcConfig.locData.FileGridSizeColumn/*,
                    setValue: function(value){
                        value = HttpCommander.Main.sizeRenderer(value);
                        this.value = value;

                        if (this.rendered && this.fieldEl) {
                            this.fieldEl.dom.value = (Ext.isEmpty(value) ? '' : value);
                        }

                        return this;
                    }*/

                }, {
                    name: 'datecreatedFormatted',
                    label: htcConfig.locData.FileGridCreatedColumn
                }, {
                    name: 'datemodifiedFormatted',
                    label: htcConfig.locData.FileGridModifiedColumn
                }, {
                    name: 'dateaccessedFormatted',
                    label: htcConfig.locData.FileGridAccessedColumn
                }]
             }],
             
        });
        
        this.uploadWindowTb = new Ext.Toolbar({
            dock: 'top'
        });
        
        this.uploadWindow = new Ext.form.FormPanel({
            floating: true,
            modal: true,
            fileUpload: true,
            standardSubmit: false, 
            centered: false,
            uploadInProcess: false,
            width: Ext.is.Phone ? "90%" : 400,
            height: Ext.is.Phone ? 300 : 400,            
            hideOnMaskTap: false,
            dockedItems: [ 
                this.uploadWindowTb,
                {
                    id: 'uploadFormButtons',                    
                    xtype: 'toolbar',
                    dock: 'bottom',
                    defaults: {
                        scope: this,
                    },
                    items: [
                        {   
                            text: htcConfig.locData.SendEmailClose,                         
                            ui: 'decline', 
                            iconCls: 'delete_black1',
                            iconMask: true,
                            handler: function() {    
                                if(!this.uploadWindow.uploadInProcess)
                                    HttpCommander.Main.stopUploadFiles(this.uploadWindow);                              
                                this.uploadWindow.reset();  
                                this.uploadWindow.setUploadInProcess(false);
                                this.uploadWindow.hide();
                            }
                        },
                        {xtype: 'spacer'},                        
                        {
                            text: htcConfig.locData.UploadSimpleReset,
                            handler: function() {
                                this.uploadWindow.reset();
                                this.uploadWindow.setUploadInProcess(false);
                            }
                        },
                        {
                            id: 'uploadFormButtonUpload',
                            text: htcConfig.locData.UploadSimpleUpload,
                            ui: 'confirm',
                            handler: function() {    
                                    if(!this.uploadWindow.uploadInProcess)                           
                                    {
                                        var curFolder = HttpCommander.Main.getCurrentFolder();
                                        if (!curFolder) {
                                            Ext.Msg.alert(htcConfig.locData.UploadFolderNotSelectedTitle, htcConfig.locData.UploadFolderNotSelected);
                                            return;
                                        }
                                        
                                        if (!htcConfig.currentPerms || (htcConfig.currentPerms && !htcConfig.currentPerms.upload)) {
                                            Ext.Msg.alert(htcConfig.locData.UploadNotAllowedTitle, htcConfig.locData.UploadNotAllowedPrompt);
                                            return;
                                        }                                     
                                        HttpCommander.Main.uploadFiles(this.uploadWindow, curFolder);
                                     }
                                     else
                                        HttpCommander.Main.stopUploadFiles(this.uploadWindow);
                                }                            
                        }
                    ]
                }
            ],
            
            //scroll: 'vertical',
            items:
            [                   
                { 
                  xtype: 'fileuploadfield', 
                  id: 'inputFileField',
                  buttonOnly:true,                   
                  
                  listeners : {
                    'fileselected': 
                        function(self, v){
                            this.ownerCt.items.get('uploadFileField').setValue(v);
                        }
                   }
                },
                { 
                    xtype: 'textfield',
                    id: 'uploadFileField'
                },
                {
                    id: 'uploadStatusLabel',
                    xtype: 'textfield',
                    label: '<br/>',
                    labelWidth: '100%',                    
                    centered: true
                }
                
            ],
            setUploadInProcess : function(val){
                this.uploadInProcess = val;
                this.setLoading(val, this.body);
                //this.hideOnMaskTap = !val;
                var msg= "<span><br/>" + htcConfig.locData.UploadInProgress + "...</span>";
                //<img src='" + htcConfig.relativePath + "Images/ajax-loader.gif'>&nbsp;"
                if(this.uploadInProcess)
                {
                    this.items.get('uploadStatusLabel').labelEl.dom.innerHTML = msg;         
                    this.dockedItems.get('uploadFormButtons').items.get('uploadFormButtonUpload').setText(htcConfig.locData.StopUploadingButtonText);
                }
                else    
                {
                    this.items.get('uploadStatusLabel').labelEl.dom.innerHTML = "<span><br/></span>";
                    this.dockedItems.get('uploadFormButtons').items.get('uploadFormButtonUpload').setText(htcConfig.locData.UploadSimpleUpload);
                }
            },
            doFormUpload : function(o, ps, opt){
                    var id = Ext.id(),
                        doc = document,
                        frame = doc.createElement('iframe'),
                        form = o.el.dom || {},
                        hiddens = [],
                        hd,
                        encoding = 'multipart/form-data',
                        buf = {
                            target: form.target,
                            method: form.method,
                            encoding: form.encoding,
                            enctype: form.enctype,
                            action: form.action
                        };

                    Ext.fly(frame).set({
                        id: id,
                        name: id,
                        cls: 'x-hidden'

                    });

                    doc.body.appendChild(frame);

                    //Reset the Frame to neutral domain
                    Ext.fly(frame).set({
                       src : Ext.SSL_SECURE_URL
                    });

                    // This is required so that IE doesn't pop the response up in a new window.
                    if(Ext.isIE){
                       document.frames[id].name = id;
                    }


                    Ext.fly(form).set({
                        target: id,
                        method: 'POST',
                        enctype: encoding,
                        encoding: encoding,
                        action: opt.url || buf.action
                    }, false);

                    // add dynamic params
                    Ext.iterate(Ext.urlDecode(ps, false), function(k, v){
                        hd = doc.createElement('input');
                        Ext.fly(hd).set({
                            type: 'hidden',
                            value: v,
                            name: k
                        });
                        form.appendChild(hd);
                        hiddens.push(hd);
                    });

                    function cb(){
                        var me = this,
                            // bogus response object
                            r = {responseText : '',
                                 responseXML : null,
                                 argument : o.argument},
                            doc,
                            firstChild;

                        try{
                            doc = frame.contentWindow.document || frame.contentDocument || WINDOW.frames[id].document;
                            if(doc){
                                if(doc.body){
                                    if(/textarea/i.test((firstChild = doc.body.firstChild || {}).tagName)){ // json response wrapped in textarea
                                        r.responseText = firstChild.value;
                                    }else{
                                        r.responseText = doc.body.innerHTML;
                                    }
                                }
                                //in IE the document may still have a body even if returns XML.
                                r.responseXML = doc.XMLDocument || doc;
                            }
                        }
                        catch(e) {}

                        Ext.EventManager.removeListener(frame, 'load', cb, me);

                        //me.fireEvent(REQUESTCOMPLETE, me, r, o);

                        function runCallback(fn, scope, args){
                            if(Ext.isFunction(fn)){
                                fn.apply(scope, args);
                            }
                        }

                        runCallback(opt.success, o.scope, [r, o]);
                        runCallback(o.callback, o.scope, [o, true, r]);

                        if(!me.debugUploads){
                            setTimeout(function(){Ext.removeNode(frame);}, 100);
                        }
                    }

                    Ext.EventManager.on(frame, 'load', cb, this);
                    form.submit();

                    Ext.fly(form).set(buf);
                    Ext.each(hiddens, function(h) {
                        Ext.removeNode(h);
                    });
                }
        });            
     

        this.items = [this.fileList, this.fileDetailsForm];
        //this.actionBar.setVisible(false);

        HttpCommander.MainPanel.superclass.initComponent.call(this);
    },
    
    backButtonHandler: function() {
        switch (this.getActiveItem().id) {
            case 'fileList':
                HttpCommander.Main.itemToSelect = HttpCommander.Main.getCurrentFolderName();
                HttpCommander.Main.openGridFolder(HttpCommander.Main.pathUp(HttpCommander.Main.getCurrentFolder()));
                break;
            case 'fileDetailsForm':
                this.setActiveItem('fileList', { type: 'slide', direction: 'right' });                        
                this.actionBar.configureForSelection();
                break;
        }

    },
    
    showUploadWindow: function(){
            this.uploadWindow.setCentered(true);
            this.uploadWindowTb.setTitle(htcConfig.locData.UploadSimpleUpload);//UploadTitle);
            this.uploadWindow.show();
    },

    folderChange: function(curFolder) {
        try {
            if (curFolder != 'root') {
                this.backButton.show();
                this.navigationBar.setTitle(HttpCommander.Main.getCurrentFolderName());
            }
            else {
                this.backButton.hide();
                this.navigationBar.setTitle(htcConfig.locData.CommonMainTitle);
            }
            if (HttpCommander.Main.itemToSelect != null) {
                var selModel = this.fileList.getSelectionModel();
                var fIndex = HttpCommander.Main.gridStore.findBy(function(rec, id) { return rec.get("name").toLowerCase() == HttpCommander.Main.itemToSelect.toLowerCase(); });
                if (fIndex >= 0) {
                    //select item in list from where we goes here
                    if (!selModel.isSelected(fIndex))
                        selModel.select(fIndex, false);
                    var offsetY = this.fileList.getNodes(fIndex, fIndex)[0].offsetTop;
                    //scroll to selected item if it not in visible list area                   
                   try{
                        if ((this.fileList.scroller.scrollView.containerSize != null && offsetY > this.fileList.scroller.scrollView.containerSize.height) || !this.fileList.scroller.scrollView.containerSize)
                            this.fileList.scroller.scrollTo({ x: 0, y: offsetY });
                   }
                   catch(e){}
                }
                HttpCommander.Main.itemToSelect = null;                
            }
            this.actionBar.configureForFolderChange();
        }
        catch (e) { HttpCommander.Main.ProcessScriptError(e); };
    },
    listeners: {
        render: function() {
            this.actionBar.configureForSelection();
        }
    }
});


Ext.setup({
    /*tabletStartupScreen: 'Scripts/logo_tablet.png',
    phoneStartupScreen: 'Scripts/logo_phone.png',    
    */
    glossOnIcon: false,    
    onReady: function() {
        try
        {
            var loading = Ext.get('loadingTouch');
            if (loading) {
                loading.remove();
            }
        }catch(e){  ProcessScriptError(e); };

        HttpCommander.Main.init();                  
    }
});


